
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']


def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    pass


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    pass


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsO*\x00\x00PYARMOR\x00\x00\x03\x07\x00B\r\r\n\t0\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x0f*\x00\x00\x00\x00\x00\x00\xda\xc4\x9fS(\xd8\xb5|\xbav9j\x96#\x8a&\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf2\x8f\x02\x1eE\xf1'
        b'\xfa,A\xaf\x82^`9\x84x\xb4\x12\xf1-\xb6\xba\xb1\xd3\xb7\xe6\x1b\xbf\xc6"\xe68=\xe8\n\xff\xa9\xbb\xefS\xd1\xee\xee\x8f(5\xa0X\xad\xf9}a\xb4\xfe\xe7\x0frL\x1c#c\xf4p\xae+q\xf5\'\xc0\xeb'
        b'\xd4\xa9@\x11S\xf6F\x9e"\xd0)\xd6\xed\x02$\x9d\x1b\xcc\xfc\xb3\xfe8\xa8\xc7o\xe4\xaav\xb4\xf5\xa2\x1e_\xb7s\xdfT`\x80\xa1]\x95\x7fi\x9b\x973\x10\xd3k\xe1\x18M\xeb\xc1}1\t\x0bT\xebn\xc5\x8a'
        b'^\xd5\xd0\xba\x0c\x96p\xeb(\xf7U\xa34\x9f\x1a\x14\xc2U$\xba%\xb1\xa6\x92>\x9c\xac\xd5\xe9\xbe\xbf\xce*4-\x91 \x9c\x8d\x1fH3g\xf3\xee\x01E\xab\x13\x7ffOq\x9f,\xa2\xed\x95\xdc\x10\x80\xf4\xf5\xd0'
        b'\xdaG\xda\x15\xc2\x8d\xdf\xd1\x99\x01\xea\xb3\xc0\xd2\xc0C dC5\x93\x80\x8f\xcf\xa0\xf0\xde\xcf\x05p*\xae"\xbb\'~>\x8b\x12l\xeb\x9ez%]\xc6\xb8\xcfN\x83"\r\xf1\xed\x8e;f\xad\xf7\xd2\x88{/\x89'
        b'q\x1cRB]\x11\xe7b,3J,X\x95\xa3\x99\x9a\xda@*.\xea\xa2\x92f\xbc\xcd\xc5\x96\x80\x10\x88B\x01s\x8d-\xddi\x96\xbduNW\t\x9c\xd2\xfbH\xdf\xcb\x11Z\x0e\x99R\xc9)\xab\xf9=\xbf\x9c\x11'
        b'\xc1  \x82*\xf1\xdf\x88~\x9e.\xe3\xbaE\xeeS^@\x80\\\xb5jh\x9f7\xcc\x8b\xf4\x9a\x80\xd9\xcc=F\x15\x85\xa8H\xe4z\xc9\xa6~\x8f\x89#\xb5\xe0\\\x9e\xb0{\x86n{w\x1d\xb6\xc4\xab\xaf\x155\r'
        b'\xc5i\xcct\x05M\xd9\x1e0B.l\xc4\xfe\xe0r\xfa\xe5\xc0O\x13\x0f\x80\x12\x97\x07\x9fFc[\x96\xec\xba\xdf\x17a\xb8\xfd\xa0\x84*y\x0br\xf0\x1c\x8b\xc9\xf5\x8f\xece\xe9\xa4\x8b\x87\x9b1\xabgro<\x9c'
        b']\xbb\xb3\x13\x81}\x18oIdUw{J\x02\x13\x99\xc5\xd5\x07\xf9)\xc8\xe4t\x1ab\xfb\xfd\x11F\xb46\xc19\xaa\x1d\x12d\x17v\xbb\x82 \x1a;\xea\xc2W\x97\xab{z6\x0f\xf8\xcc\x10\x8e7\x18a\xdat'
        b'\xd82\xebJ6dJp]o%\xd2\xc8\x94 f\x1a\x1c\xb9L\xbfx\xa3\xc2\x02;\xcc6\x1ez\xaf\xe9\xb4\x807,\x88\xc1^\x1d\x06\xc7Yd\xf7\xfc\xea\x18\xfeB\xb7\xe4\xe5\xe4\x05\xe4`r\xa8\xd7\xd3\xeb\x81\xec'
        b'0\xc8|;8\xd7\xca\xa05\x8a\xf8\xa0\xd5\xfb\xab~t\xfb\xcb\xf5\x9a\x1erT,\x02+`\x81\xd57\xc2\x96[kX\x03&m7\xd0i\x8c\x9eu\xb8\x13 \xeb\x8b$d\xa1\x1e\x85&9\xd4\xef\xe7\x7f\x82\x9e>'
        b'\x9e\xf2\x1a\xa3\x7f\xd1\x8f\x91\x80\xbao\xdb\x0eO\xb1-\xdb\x0e\x03\xf0:\x82\xe97\xb9\xba\xf9\xec\x83X\x9dc?\xbb\xac\x19Hs4\xa1\x7f\xc5S\xeb\x11\x9c\xa2\x98\x98\xce\xe2;\x02-%\xd5\xbb\xdeAt\xdb\x19\x83z'
        b'\xeaa\xf8\xd0\xd1\xbd\x9d\xb9\x8d\x04?\xa0\x11h#9\x8e8\xea\xd4m?R\xd7\x90\x7f\xa3\x9e\xe7o\x9dt`\xfd\x80<l\xc5\r\x08\xa6=\xfc\xc3\x90\xc1\xf6\r\xcf^\x97Q<IO\xa8lX\xde\x1a\x11\xa6?\x11'
        b'4LQ\xb2p\xa3\xfbj\x83\xb5Q\x8d\x85\xea\xcf\xdc\x8f5\x86\x82n\t\x06-\xdbm\xac\xde\x02\x81\xf2,\x9b\xafg\xa3\x9et\xb1\xd3\x92!\xe5vb\xd4P\xb8\x15\x89\xc4o\x95\xbc5\xac_\xd4\x80\xc7\xeb\x9f7\x86'
        b"a\x1f|\xa5\xb2\xf7\xeeFr\x1d=\x91\xc7\xf8\x80\x84'\xfe\x02\xcd\xda\x96\xb7\xa0\xbe\xee\n\xf0\x84\xaeo\x08\xc2\xe6\xc4<\xee\x8c\xb5\x05\x98\xa2\x81\xcd\xb9w~\xd4\xdf\xc6y\xd6@?\xc9h\x80\x9d\xd1\x991,\xbf\xb8"
        b'\xa9\xc2\xcaY\x86\xbe\xc9\xcb\xea\xe4\xd6\x8b\xac\xf2\xf3\xa8U\xcc\xd2\xdd\x1a\xd1\xaf\xa5\x80\x8d\x98\x91J\x0e\xac\x9b\x07\x8f\x12\x85\xcd\x06\xda`r,\rO\xb5\xe5#\x8b\xbd\x8f>mkU\x87\xb33J\xbb\xd2\x94\x97\xc8\n'
        b'\xc7@sk\x95\xb1\x020 \xae\x98\x80\xf0;w<\xe5%\x95\x173\xee\x992\x91\x03\xdf\xfe\xf2\xd3)e\x92\x9a\xaa\xcf\x9e&\xd8\xfdN\x98\xde\xe5\x85\xd8j\\\xd9\xe1\x03\xdaSW\xe8\x8b\xf4\xecp\x9c}\xcaOF'
        b'\x02\xc7\x96\xb0\x8e#CKTI\x85|\x8d\x07uWe\x1c!\x92\x11N\xdc\x05\x9a\xe8\x8b>v%\xd5\x14n\xa7\xda\xa1B\xd9\x85l<\xc0\x92X\xa05\xf8S"W\r\x10d$(\x1b"V\xfbF\xb4t\xf0\xab'
        b"\xc4\xfay\xe2(\xffiyZ\xf0\xb9|\x8b\xc6\xb0\xdb\xb3\xd5\xe7\xe8\x1a\xce\xacc\xba\x92\xf6\x17\xb9\x9dB\xc5\xf3\x04U\x0f'(Ui\xdf\x9a\xdd\xb7\xa4\xf1\x95M~\x8b\xe9d^\x7f>\xfcJ9Z{r=\x0e\xc9"
        b'\xc44\xea1\xbd\xc1b\xff\x0e\x04\xc3\xf3\xac.\x93\xdf\xab\xf6\xa8\xc05O\xb4\xe1sb1\xca\xa3J\x0eI_\xad\x96\x819\x11\xb1ER2\xd0\x89\xb2a\xa9n\xeb\x0b\xde\xf1\xf4\x89&\x0e\\ayZ\xd3\xb1U\xfd'
        b'CX\xfb\xf7=}T\xb3mt\xea\xfc\xd4\x07\xe4\x0f\xd9\xefj\xe1\x81\x82\x02\x04\xb2cn\x8c\x89Xt\xa8cd\xa3:U\x17\x17\xb3^\xa7T\xbb\xf9\xd4&7\xf9V\x9b\x85\xd1\xe9\xfe<*\xe4\x8d\x12\xf9:\xfb\xea'
        b'\xda\x1f\x12\xe8\xccJ\x1d\x9f\x05\xb6T\x1cx\xbfq^{%CW\xfa;c\xdam"\xae\x0e\xd1\xcd\xe3\x14hK\xf2\x17\xff\xd7*<\xe1\x08\xde\xea\xb1\xda\xe2\xea\xb7\xbd\xef\xe8<\n\xdfDj\xc4\x03HC1\xc3\x1f'
        b'\xd0\xa1#\x8f\xdd\xd2\x7fc\rn\xb9\x86\xcb\xff\xf5u\xc1,\xb95\x92j\x7f\xb1+\x9f\r\xe3FJ\x03\x810)\xac\x17\x08\xb4q\xe2\xb7,9\xef\x8c\x15\x8cc\x87\xc1!\x8eC\xe9\xd8\xed\xb3\x8b\xdaH\xcd\x07U\r'
        b'\xed;M(\xee"l\x92W!L9u\x1b\x0645S\x1fM/\x89\xddt\x19\xca\x01L7\xf7l\x96\x9amr\xd9x\xc9\xc2=\x99\x93\xd5\x07\xa5\x1ad\xcc\x8f\xfcR\x93|\xd2b\x88\xe6b,{\x00\xfb\x9a\xe9'
        b'\xf9\x92i.\xdf\xc7\x17\xd0\xda\xc3\xfe#\x18\x86g\x0b\xe0Q\xf8\xb0\xb0b\xa0\x87\x16\r^\xa5\xccsW^E\xd2\x06\xa2=\x9d\xfb\x92.\x17\x96\x91d:\x87\x90\x11\xde\xf8\\\xc9\x89\x91\xa4\xc9\xb3p\x8a\xc9\xd2i\x08'
        b'=X\xd1\x95R\xfdI\xe7p\x8cq#\xe1\x7f\xff\x97\xd9R2\x89\xbe\xe2\x18x\x15\xbd/\xf6\xc2b\r\x8c\x00\xbb\xfb\x1c\x92\xcb\xd0y\xf8\xd6d\xb0gw\xc9\x9d\x06f\n\x9f\xbef\xc2\x14\n#\xc4\xf3\x8e\xab\xe5-'
        b'\xa58z\x18\xabJ\xa2\x98\xe5\x9aW\xda\xcc\xdaC;\xe9\xca\x96\x1b\x08\x0c\x83k\xfc\x8f\n\x0f\xc4M\x941\xaa\x97\xa2yE\x15\x0e\xbd|\xd6\xe2j\xf7\xc0j9\x92\xcb\xc0\xb5\xc4\xb0o\xfa\x99\xf78\x19*\xd5r\xcd'
        b'\xec\xef\x83\xd5I\xfbH\xff\xab\xf5\xbb\x99\xa2\xed\xa1\x89\\\x04\x03=@\x0c\n\x95H^\xa4\xc5A\xe5\xc7\x85U/\xd4\x1ee\xed\x82\xcfVk\x83!\xfe\x8f\x8e\xf6g\x9c\xd9\x1e\xd6\xc70rh\xe3\x96\xa7\x06S\xbcL'
        b'z/\xab\x80\xb38\xa4aP\xe8\xe3\xc7\xef\xe9"\x90\xcc\x07l\xae\xcd\xf8\xb4&\x80\xe5\xda\xebK\xa9\x88\x14\xc9\xc7\xd5:\xf3D\xd7b^\xbb\xee\xd4\xa8~\x9an\x14\xadAU\xe0L)\x04\xaa\xc2M/ .q\x91'
        b'\xd3\x96hv\xed\xcf\xech:4\xe6\x15\xd3#\xba\x10\x0e\x1eJ\xf5\x81\xbf\x80\xe86\xf2\xb8\xc8=\xb8\xba\x8fR\xa9E\xae\x17\x81\xcal\xc6\xe1#\x9e\xa1\xb2\x07\xd7\xe5\xf5\xa9)c\x1aj\xc7U\x81\xeb@\xd3\x1e\x7f\xc2'
        b"8I\xed%\xa5\x8bHH\xf6\xd4\xd5\xe5|8\x11\xb6\x06\xf7_\xc6mGF\xfb\x1e;h\xcf\x07\xcf\xc7\x0f\xce\xb6\xc7\xa8\xe0y\xe0q'K\xbcQ7\xaf\xc7\xc1\x9f\xcdk\x02Rv;\xda]|.\xebX/j\xbb"
        b'_\xf7\xce\xbbU\x1f\t\x16,d%\x1fv\x93N\xfc\x8d\x14\xd9\x8a\x88d\xc7\xd5\x8c_w\n\xed\xfe\x15\xc9kQ\xdd[P\xc7\x96\xda\x848\xf3\x1bPo\r\xbfVFd\xcd_\x88""\xc7\xb9\xdf\x1d\x83\xe63\x8c'
        b'l\xd2\xcd\xc7\xa3>i\xf7\xaa\x11\xfa\xcf\xbc\xd1}\xa8.B\x8a\xf6\xc4\r\x8c\x1e\x8f\xc4R}\x87\xed\xe7\xf9\xe3\xec\xc5\xbfz\x85\xd0\x06c\xe8C\xfc^ewh\xa7\xc8\xe0c\xa0\x91\xb7O#0(oM\xbe?\x87'
        b'\xb1\xb8\xf3\x89\xd40\x7f\xbe\x86\xc8\xde\x01X\xfdT\x0b\xe6\x1c\xf16\x987\xcf\xe8ip\x9a=\nN|(\x98t\xf8\x07Kc\x94\xc8k2iK\x08\x81t>\xc4WL\xc3\xc0<\x92\xd4\xca\xb2\xef\xfe\xd5F\xe0\x14'
        b')\x1a\xcc\xd0\xe4ph\x1c\xac\xa2\xce!RE\xc9\xb4\xaeC\xf5f\xacX\xd2\x9a\x19Uv\xd9\x12\x99\xe6\xcb(=\xcb7>\x13\xa3y\x10\x1f\x0cdKR\xfb\n\xdf\x863:\xd0\t1\x1d\x92\x9b\x0f\xed\t\xde+\xd3'
        b'\x98\x94#~\xe7\x1f\x19\x88\xf3\xae\xf31\xf1\xb3\x9b\x16\xac\x90!\xf0\xdf\x12\xcd\x81\xc5\x01\xa1`\xd5>\xcf\xf3J\xae\xb7iG\x18\xbf9\x19\x1c\x9d\xaf\xaa\xa1\x99\x8by\x08\x9f\x84\xddd\x1esz\x1a\x03\x95p\x1d!v'
        b'\xbbI\xfc>\xda\x99\x8c \x1cD\xa1\xb0\xa2\x8b\x94Y\xca\xde\xe9\xa9,\x9d/\xbcY9x}P\xe1\xfeO\xe3m\xf1\x1dC8\xcc\xfe\xdbYRV\xcb\xca\x117\x84\xb1#I\x017\x9b\xa4\xffa\xe3)e\x8c\x88g'
        b'\xe3h8\xd4o\xfbK\xdd\xd8\xda\x8c\xa2b\xb1\x03$":\x08\rKTrMG\xdb\xfd\xf7\xfe\xe5\x83MB.U;\xdf\x123\xb3\x987\xba\xb1\x8c\xba\xb8S}\xd3MR1\xeao\xa0\x87\x04\x89/\xc7jG\xd7'
        b"q\xae0\xdbZ\x93t\xd7\xd0\x87-\xec\xdf,\x0b\xee6\x11\xac\xbb\xcd\x8c\x86\x1e\x80G\xdfT4\xa7\xe4\x9d\xf1?V\xd4} \xd0m\xd9'\x88\xb1\xfbK\x96+\xa9\x14\x19\x96\xe6\x85\x1e\xc1\x04U\x9d\xcb\x9c\x11\xb1+"
        b'>\x07\r*\x9b7R\xcd(#\x94j7\xf1\x8e\xba>O!\xca\x13\x98\xf6)\x14\x8b\xf4\r\x99\xc4g\xe79\x8fmp"&\x94\xd24e\xf5M\x13\x92 \x8c\xed\xfbw\xabp@Q\xe9r\xec\\\xf4\\\x03\xd3x'
        b'_\xa7\x1b\xf8N\xb9#\x9a;JH\xa8;\xa8\xe0\xdaS\xc9\x05\x97\x06\x0f8\x18\xae\x11\x8c\x98\xf2\x8fCPZ\xbep\xbdV\x1f_\xaeq?\xbf\xe0\x1d]\x8f*\x024\x8a\xc6\xe8,\xdd\x18gEL\xeb\xdc{\xc6s'
        b'\xec\xf8y\xaf\x9e3\x0c\xb9\xa4e5b(\x9d\xa0\xed\xee\xeb\xf3\x1aQ\xf7\xe4EG\xb9O\xa8\x08:\xa2\xfc\xb9O$9h\x01\x1a\xa9\x8c\xd3?\xb5\xe8\x08P\xa1\xa3W\r\xcc\xe1\x9b\xc4$AB\x14\x80\xf2\xd9Ft'
        b'mD\x97@\x0e\xa6\xd3u\x8cbw\xe4A+\x1c\x8fi\xcf\xbf\x8e\x17\xa5\xed\x08x\xc0dQ\x18\xb6N\xb2\x9a\xc4\x84\x8d\x1cCC\t\x12\xba\x13\xf4t\xa2\xa3\xfa\xbf\xa7\x0c\xb98\xe4l\xd6\x8a\xd4\x15\x19\xb04\xd0\xd7'
        b'\x81\xc4\xee\xb2\xf8\xad\xb16\\\x8f0\xdaD\xff<\xfb\x98&\xd3F\xdf`/\xbb\xa4\xedv\xb1n\x8c\xc6\xd4\x7fE\xb8\xd6\x01\xdc\xb7\x97J\xe0\xcb\xc2\xf2%pJ\xda\xdc\x86\xc6\xc4\x88\x94F5\xab\xf2%,G\\\xeb'
        b'\xa6\xc7\xac\x85n\xf4j\x8e\x10\x8e\x9f\xd6\x03I@\x91jF \xfel\xa5]\xe8\x07\x04\x0e\xf8\xa7SJ&\x92\xab\x08\x19k\xe6\xfe\x9b\x89\xb1\xd9\xd2\xf8\r\x98\xa1\xbf\x8c\xc602\xccr\xc4\x0f\x05\t\xcdl/vF'
        b'N \xbf\x17\xc4@\xc37bx \xfd\xb3\xed\xd0~\x89\ncL\xdd\xdc1@\x9f\xc1]\x17\xbb:\x1e\xcb\xd4\xce\xba\x81F\xb6:\x0e.*0\x031\xc1\x1e\xfd\xadT\x99\x82*\x8e\xe9\x9c\xe2 h\xda\xe45v\x1f'
        b'\xef\x91\xc9#\xc7\xd0,\xf3\xf0\x04\xf3\x07\xb1a\x04\x8a\x92\x9a\x18\xd9\xc4Z0\xd3\x0b\xb7\xae\x13\xd6\xd9I\x1e\xac\x94\xab\xaan2\x8b\xd4\x1e\x03\x08yoY\x1f.\xd7#70`\xe6\t\xb3\xcb\xd2\xe0\x82pUR/'
        b"\xc1\xce\x88x*z\xb7M&ZpB=\x1bj\xc4\xc9Os\xc6\x8eF\x9d\xca\x0e2\x11^b\x81\xafG\xc5\x1dy\xfd\x94\x8e/`r\x87\xa2<\xf7\xb7\xf4?Z(\xb4\x9f\xa7[\xc4\x90a\x8cn\xac'\xf7\xa3\xae"
        b'\x8bo\xf3\xac\xbf\xb1\xcf\x91N\xfb\xcc0-<\xc6\xaat\x87 \x81<`\xce@\x19-}w\xd0f\xfc\xde,[\x8d\xf1,\xb9%\x17\x95\r\xcaJL\xaf\x80\x9b\x81B\x82\xec\x84,";S\xd3\xc3\x8f\x1fOg|'
        b'\xcb3\x9c0!\xed;"\r,\xf1H\xd1\x13 6Or\xba\xfb\x00\x92|\x0f\xa5.\xf6/\x84\xb4\xa5\xd2/\x8b\x11\x94\xb5A\x1fp\x86\x17\x98a\x05\xca9\x82\xe8(\xce\xde`\x8b\xc6\x1c\x07)q\xfa3q\x00\x8a'
        b'N7\xbe7\x84\xd4D\x86\xcb\xdd*\x88\x93\x14\x8d\x87\x89q\x86\xde\xa6\x15\\\xcb\tY?m`\xfe\r\r\x9c\xccuR\xc3~\x06=\xf3\x90\xae\xd8\xa6\x95\xf1ak2\xb6]\xed\xb7m\x17\xf6\xf3\xccL\xa3\xd4\xea;'
        b'\x0f\x80\t\x11\xd0w\xe6\x87O(0\xab\xd8\xc2\x80\xa49\x11K\xf0\xeeB\x1b$\x9bS\x91.V\xa2\x15+\x91\xecD\xaf\xe1\x0b\x1a\x8c\xd8\xd5\x02\xcae\x00\xeb\xd2e@Ao*L\xdd\xfd\xd3\x17\xdb\xf3\xc7\x8c\x84z'
        b'c\xeb\x1aO\x83\\P\xaf\x85c\xe27@\xfd\x7f\xb6o\x83r6q\xe3Z]I\x8c\x85S\xd9\xb6\x11\x8cP\xef\xa6\x14/D\xb22\x82\xb6\xe7$C\nNt\xa4g\x1b\xafA\x9d\x85>\xa6\xc4&\xe6W\xd5\xb8\xac'
        b'\xf3\x1db\xdb\\\xc1\xb8\x9e\x82\xa3!\x11|r\xfc\x9btA\xad\xac\x9b\x1a-\xbe\xa4y\xea\xf1\xc1\xd5\xc0o\x19\x1b\\\xd0\x1b\x9a!\x1cb\xc2~\xb4d/\xc3%\xacu\xff\x18\xbb\x16\xb7v\x99T\xf0\x99r\xe0\xbe\xdc'
        b'IT%\xd4B\x9a2\xf7\xf11N\x81u\xde\xc0\x99D\x815\xed*Ix\x91\xd2CR\xf4\x16#\xa2\xd6\xf5\n`q6\x19\x12Ft|<\x7f\'\x0c\xcar\xd0\xc1\x90\x8e\xd6d(\x8d=\xf3"\xe2+\x89\xf3)'
        b'8S ;\x8b\xb3x\xa3\x17\xa8Z\x10\xf8e7j\xce\xc9\x81\x88z\xf0U\x1a\xbdmt(\xeb\xe9J.0N\xed6\xdf\xf1\xf5\xfdZ\t\xa8\xe5-\x1b}\x06\x07:\xca\xa9\x02\xc7u\xd1~\x0b\xbew\xd1\xc913'
        b'd\xf3[8*\x92\xc7\xb2\xa4\xd7\x07\x9a\x14C\xb3\xe4\xb6\tI\xce}\xb7\x15@e@N\xb1\xb8J\xaa\x1b\xa2\x80C vI\xac\x00\xdbO\xf6{;\xa6\xd8\x15\r\xfbf\xb1\x9fK6\xe8\xb3O\xc5A\xff\x10\xb9\xd0'
        b"\xc1\xe3\xd0\x18\x93\x94s\x88\xb7\x06\x1e\xaf\x91X\x16\x97\xd4\t\x10\xeadE\xf6\xcan%\xa0\xd7\xc06`!\x1e\xb7'9\xa1\xb3*\x80m7\x97\x1e\xd2$\x01f\xf0!y\xbe\xf0\x82o\xea\xb7\xc6c\xc3\xc5@\xae\xda"
        b'\x9f\xe7\xb1U\xa3p\xd3\xa2\xfa\x15\xf9^\xc8+\xc7]<<\x03\xee\x90\x97\x06\xf9\xa2!\x85\xfa\xc7\xdbx!\xb6\xc7*\xfb}\x0eJr4\xa1j\x9a)\xec9-\x16L\xa0e\xc3\xa0u6 \xfd\xee\x9e\xfeNL\xc3'
        b"\x1ft\xfd\x165\xb59\\'l\xb0\xc2z\x0fb\xa4\xcc\x99\t\xdbZq\xd5-\xf8%\x0c\xaf\x1f!\xebN\x89\xd92\xb0\xac\xb3\x9d\xd3p\x055\xb0=_\xed\xb2\x7fD\xb0t\xc6\xf5\x169\xfc\x1fj\xc6\x1a\x83\xf3\x81"
        b'\x0f\xed{\x95+<\x81Jw\xfd^\x97\xda\x1e\xd8\x84\x12\x8c"\x02K<[\xce>\xc5\x9d\x13\xe6Q\xdc\x9b\x0f\xe9\x88\xe1]\x1d\x18\x0e\xbf\xad\xa8\xfa\xc4\xf8\x08\xc2\xf9\xca$/\xb6f)d\xf18\xb7\x13\x03\xad\xe4\xe3'
        b'fM\xec\xb4H8;\x00\x89f\xf4\x96\x03\xf2E\x95\xfc\x90\xe3\xd2\xb6Si\x16\x01\x05aj\x11\xde^Q\x86\x9bJ\xf4D\xbe\xb0\x14\x96\xd1\x90\x03\xc7)\xf4\xa5\xbd&",\xdaL\xafq}\x1d\xde)\x18$\xe4\x16'
        b'0aQ\xa9\xbf\x19\x95E\xb8\xe7\xaa\xf7?G\xe0?\xfc\t.l\x1f_\xc7\x81\x8eo\xe3\x8d\xa0\r\x088\x07\xf2\xe2=\x80\x87\x13{Ph\x05\xc6\xd2\xaa\x06\x96/\xba\xd7\x01\xaf\xeb\x9cj\xc9\xdb4\x0f\xc8I\xae\xe6'
        b'\xf7(]#\xf2\xfd\x7f\xfdX\x8d\x11\x02\x92\xa3\x11\xfe\xe5F5\xf6\t\x87q*\xd6\xb6\xd3\\\xb3\x02\x84 \x8c\x80(\x1f\x9b2\x96D\xf2\xbb\xf6\xa97\xa4\xbf\xb0P\x0b\x12\xb5\xc1\x14j\'\xff\x13\x08\x11"#\xfa\x05'
        b"\x870_\xb6Dq\x0f\xd5\x1dC\xb3\x15\x90\x94q\x0f\x0f\x12C\x9e\x8d\xcf\x111\xbb\xab\x11\xc0\xd8\x8b\x8b\x01\x0b\x1bO\xa4\xb0\xb6\x0ewT\xb1\xf1R\x13B!\x80\x87\x11'\xc7\xb3\xa3q\xa0\xd8s\xb4\x1d\xab\x91yr"
        b'\x9evax\xden\xae\x84/&DKpx\x83;#(_\xb4\xe3\x9d\xe6r\x14<\x18n\xceX\xd79\x0b\x04\xd7\xeb<\x10\x08\xac\x11\xe3"\xe4\x8e\x9f\x00\xcc\xd5\x8bf(g\xad\xdb\xaa\x05\x17A\xea\x999R,'
        b'\xdf\x8c\xe3\x8fxn\xbe\xd1\xec\xbf\x0f"7\x12\x06_\xe1%\xa3V\xa6\xc1\xf4\xad\xf7\x07\xf5\xeb7F!\x81I\x98E?\xa1\xe1\x83w\xbb\\; \xd5\x12f\x99\xc1{\xe05\xb4\n1\x15#\xcf<\x8ac\x85\xf68'
        b'\xd3\x05\x14\x17\x82P\x07\xeaP\xc8U\xd8k#\xf9\x16W\xe4d\xa0\x1b\xc7\x9a\xe1\x05.\x8b+\xc4\xb4%\x0f\x98\xba\xe6\xaaE\x9c\x8b-\x04^>\xacf\x8a\xfe\x0e\x14\x1f\xbd\xdb<]\xce\x88\x19\xf5\xbf\x12\x97\xd9p\xc7'
        b'\xd4\x91\xc4`=\xcc\xd1\xaf\xa8T3\x05\xa35\x89\xb9,\xf9p\x1b\xca~\xc4n\x8f\xaa\xc5D=$\x80\x14\xaf\xa9\x0b\xf6\x0b N\xe2\x1d\\\xc9\xa9\x00^-\xc4w\x1c\x10\x19<\xf4\xf4\xbb\xe5>\xd5\x9aUgO\xa7'
        b"\xde_(\xc2\xd52\x01n|\x90\x8d\x06\rqT\xc4\xf0\x1d\xbfv\xcf\x19O&9o\x15$\x97\xb5A\xcfq\x964'\xf8\xdc\xb6\xab\x7f\xa1\xf71\xa9\xc8\x83}\t\x8cRX\x01-\xf4\x10\xc3\xf5\x1f\x12\xe3\x00tQ"
        b'\x88\xb1\x15\xb9\xeb\x82~r.\x80&%\xe1A\x14W\xbcR6\xf3G\x9c(\xa6\xc4\xb8\xaf\x95N\xa3\xa6\xa7\x99\xfd6\xe2\xcd\x02.a\xb2\xbd\x90U\xdb{$"\x96\xbd\xf4$\xfb\xdcL\x02\xb4\xaf\x1c\xa4\xda9Fu'
        b'\xce\\\x1e\x84v.\x0c^ZN\xb4\xb4J\xe8@\xe6\xfa\xdb\x8b\x04X\xe1\x10P\x90\x1d\x89\xe6S\xbf6\x89\x81\xb6Tj$\xe2\x88\xb12\xd0\xfb\xff \x02\xa1\xdeT\x81\xd2\xdc\xea\xeb4G\xbd\x93\xf9\x81\x0br\xafe'
        b'\'I\xfa\x04\x16LW\xa3\xed\xc8_8#\x83\x11\xc0\x00\x8eE\x84TD\xed`\xa1\xdd\xe1c\x8d\xb3c{h\x02\xd9\xa2\xbf1\xdd\x18\xba\x1c\xe4"`\xbc\x0b>\x84\xd1\x01\x89\x96\x98\x97\x98\xebMFkT\xb6q\x8b'
        b'\x1e\r\xedl\xda\xe52\x1c\xa2\x0e\x8f\x18ZB\x1e\xef\x0e\x11O\x81\xc5,\xd0\xc6\xb6\x98a\t_`\x96~\xdc\x9a\x05\x93\x89\xfaM\x8a\xd9?XJ8\xbf\x84\xd07$\x1a\xfa\x8bw\x06\xb6\xdf\xb7I\xcb]\x94Xz'
        b"@\xe7\\#\x16T\xfb\xecP\xf6\xbf\x80\x8cx\xb4\xc7imt\xe5\x14h\xfc\xfcs\xf6\x15\xfc\xa0]\xf5\xb0\xeb\x196D \x8b\xd5&Q\xabD \xb0-\x95L\xfd\xa1\x1e\x82\xc1\x84\xd8'\x8a\xcfV\x1b`\xeed?"
        b'\x85\x1d$Jg\x8f35\x12\xd0P\xe6\xd2\xa8,\xb8|L\x18\x93\t\xbeCX\xbc\xb2\xd0\xd2\x0f\x0c\xe5\xbb\x9d\xe0\x1cpL\xafH\xb9\xe4P\x14\xc0\x98%@{\x04\xc17\xcd\x8f5\xb1\x114\xd7\xe8\xc3\x08cj\x85'
        b'\xe2>\xe7\xf4\x81\xfe\xa0\x1fW\x04u(?e\xfa\x06N}\xa5\xde\xd3\x83\x9b<T{\\\x0f\x03\xcb\xb4\x89b\xf1\x10\xc3\x8f\xbc\x88\x98yl\x92E\xbf\x96j \xf5\xba\xee\x00\xd1\xabw\x17v\x7f\xbf\x8c\x8e\xf3\t\xab'
        b"r 8'\x94\xec\x93n\x9e\xc9\xb3\xc3\x14R0\x97\xc7pk\x87\xba\x82\xe0\x81\x12\x93'\x9aE\xe0\x8dX\x8c\xb9t\xd3^d\xd9\x19\xea\xfd\x8b\xfc\x98d\xab\xb0\xa2\x97-;\xe4\xd0B\x18\x9f\xebdX^\t\xde\xcd"
        b'L\xea\xdah\xafG\x9d\xe2o\xbb\x93\xb2)\x82\x9b\x86\x92\x12~+\x04P\x88\xc1\xa8\xf1/sd92\x81\x94\xa95\xf5\x01&\xe5\xff\x19\xf7\x95\xd2\xce\xbd!\x16\xfe\x93\x10z\xf7/\x944+3p\x1e\x1bj\xf0+'
        b'\xacM\x11Y)\xe2\x18\x84\xe9j\x80s\xed\xf1\r\x83\xab\x16P\x1a\xd3\xf3\x9f\xb8f|\xa5\xcd\x8f\x97\x05EW\xc4\xe6\x80~\x9c\r\x16U\xe6P\xb7\x8b\xf5r(\xaf\xe0A\xfb\xf8w\xcf\xbc\xdd\xf2i\x82\xed\xa95\xad'
        b"\x9d\x7f<xz\xff]\x0bAb0R\x1a\x18'\xce\x14\xae\x8e\x8b\x82\xfd|\x1e~\xe9\xf8\xb2\xdaT\xe4K{0\x87@s{\x12\x1e\x8da\x1b\x86\xf3s\xdd\xcf$\xfdZ\x12n\xa3qE\xc5[\xe9\x82\x17$\x9f&"
        b'Z\xe4\x01a3\xbfm\xd6>\xc3x\xda\xb5\xb5\x14\\\x08\xc3\xcc\xaf\xf8\x04\x82\xad\xcf\x05\x01kvO\x17\xb6jj\xdcIf\x9d\xae\xcf\x9b@\n\xe0$\x1e\xb2\xc4L\x82\xa2\xacuk\xcd\x91AS\xa2\x9e3\xc6Gu'
        b'\x14,\xd3\x03"=c\x10Kb\xf5\x9b\xc0\x90\xfc\xd9\x90\xc3\xc0\x14?\xe5\xeepQ<\x99^X\xb3=\xaf8\x7fA\x1cV\x19u\xbf\xe0\xe9\xfdC>"\x8f\x1c"\x86a\xdc\xbb~\xd4]\xb4\xf7\xc3Y\xe6\xc9\x97\xa3'
        b'\xdaD\xacI#_W\xba\xa6\xdb8\x10"\xc3(\xe9n\xf0@\xdd\x05\x1f\xb4\xb1\x97\xcb\xaa\xbe\xe6i\xab\x06\xac\x91\xc7\xc0\x91\\\t\xe3\xd7\xa7\x00\xf2\x1b\x02\nX\xe0\x99\xd0\x8dd\x83\xc1o\x19\r[b\xfd\x96M\xef'
        b'\xe93\xc9j0\x85\xd4R\xef\x97\xf1Yc\xc4\xb4&\xf3/7\x86\x83\xba\x13\x0c\xed\x10\xbd\x8f\xd2mhk=\x05\x1c\xbc\x99\x13F9Z\xc7j\xc8\xca\xd4\xef\x9b\xa2Y\xb3=\xf2\xae\xad\xb1\x10\xeb?Y\x8f\xa0\xdb#'
        b'\xbf\x12F\xe4\x9fD\xe3\xfc\x86\x9d\xa3\x8b\x84\xef\x1b\x9f\x13\xfaE\xcf\x08!\xfdG|\xf2\xe8\xa3\xff\xccQ\xa8f\x9d\xbe\xe5~\xb3\xe2(6X\x90\x91,t3\x1d\xddN\xd3\xb9\x1b\x1e+\xfe\xc2W\xf8._\xec[\xf1'
        b'l\x8b\xe6\xc5\x97D\x0b\xa1\x0e\xc8fT\xd7F\xc9E\xe7\x17\xd9\xa9\xfe\x1d+(\xf3\x007\xbd6K7q\xa0\xe9m\xfe\xd7\x14\xab\xe9l\xb1~\xee\\d\xd9t\xc4\xc1\xda\xf8\x86\xd2x>\x0f\xf4\x9f51\xca&\n'
        b"\rV0\xe9H\x0bA0\x9c\xba?\xfa\x000C!\xd6'\xe5n69\x8e\x98\xb3\x0bP\x15o,\x16\xbd\x0f\x16\xbf\xc5\x89W>[\xa1\xbe\xd4\x01\x15_\xdf\xb7\xd5\xdd\xe5\xa2!\x0f\x13\xb99\xab\xdf\x8d\xe7B:\xe5"
        b'\x8a\x11\x1e\xea\xa3\xf9\x97\xc9\t\x9e8\xc4S\x9a\x918\x14\x9f\x94\xef\x95\xf1C>l\x08\xbc\x8a\\\x87D\xf8\x94\x157kU\xac}m=Z\x8a\xfb:\x81-_*\xae\xd6\xad\xc3\xfd\xdaZ\xf0<@\xa9c\xec$\xb7'
        b'\xb6\x1dxBI-\xb6\xd2sg\xed\x12d\xb7\x19];9\xbcHjI\xd7\xe9+;.\x89\x9a\x18\x92\x94\xd4+\xc2\x02\xfa~\xae\xad\xd0\x9a#\xf0\x7f\xfed\xd4/X\xd7W\x84\x12.\xa9L\x12/\x9e\xd2\x07\xd5\xb9'
        b'\x1f\x0b\xef\xaf\xdbu\xa1\xcf%y\xc2\xb2Y\xc3]H\r\xd6\xf3\x86\xc2\xba\x86>"Ic9\x82\xfb\xb0\xdd\xd4\xe7\x99]\xad>\\\x8e\xf7\x05\x9ax1f\x08\xf7\x02]K\x11\x80E"\xbe\xf2v$\x01\xa9>\xb0\xda'
        b'\xbf7\xda\x01v\x01\xa4eH\x13uk-U\x0b\xfb\xfc\x80\xe2\x05\xf80\xa9\xad\xb9\xe3\xdfU\x1a\xd6w+\xc2\x07\xf2\x97q\xe00\xab\xc5,\xf4z\xa8o\x9a&\xf0\xde\xde2\xce\x87\xd2\x88\x1e\xaf\x84\xae&\xe6\tC'
        b"-\n\xe5\xf5#\xc7\xe9\xd1!_\xb9&\x8c\xd7I\xbc\xa5Sb\xab\xc7\x01\x8d8\xb6\xd5\x87\xfc5\xfc0\xc6om\xe5\xb6+\x91\xd0\xb4A;\xc4\xc3\xf2\x16\xc8\x8b\x1c\xc2\x1d\xa2\x08J\xa3\x896\xf6\xe4\x9b\xc7'\xcb\xd1"
        b'\x9b\xb9M\x97nz\xd5<T\xa2\xcf\xa6\xae\xcfvx\xfd!T\xba\xa5\x13k\x08\x18"V\xda\xc4\xfe\xf7\xbb\xe3\xf9o!K\xc5\xcc\xfc\xca\x1c\xc7\x83\xde2\x10j\xbb\xb5k\xbf]P\x97\x8e\xdb\x02\xf5\xfa;\xff\xc7\x9a'
        b'i\x03\x9f\xfbHb/2Z\x9e\xa5l\xc20\x1f\xd8\x03\xef\x00\x84\xd8\xca\xfb\x03\xbb\xed\x1c\xddS\x04n\xc3{;\x07\xd8\x1bs\xd6\x9c\x05\xc3\x04kAF\xb3j\x95\xd2\x99\xfax!u\xd7\x91\x135\xe4\xe9\xb5\xde\xbf'
        b"\x15\xf9>\xcb3\xc7\xd8\x06\xd5\xb3\xf75=0E\x96j\xcd\x9fU\xac\x05 \xac\xe3\x9d*]W\xc9\x06g\xd0\xac\x0eU\x96\xa5\t\xd1\x00\x0e'\xf13:;\xcf\xe1\x910K\x8b\xb7\xde\xf0Q9\xe1\x94,a\xafV"
        b'\x81\x81!\xb0\xe6b\x16i\x13yqP\xaf\xf1^\xd5\xe0ux\x8f\xb2\x06\xd3(\xd9\x12\xbc\xf1\x94W\x9c\xfb\xc3\xca\x9b\xfa\x13\x85K\xc4\xcd\xc3\xd9d\xf5\xfc\x0f!3;\xc5s\xc4\xe7R\x8b\x84\xf2-L\xb9\x00\xe5T'
        b'L(\x98ee\x05\xcc,\xf9x,\xd3\xd5LoY\x17\x10\x84.t\xef\x1d\x89XWm\xdd\x11\x03u\xb7j\xd6\xe0f\x10\x96\xd1?j\xa4\xd5\x99\x97u\x1b#nF\xd8y\xdd{\x85\x9c\x16O\xe7\xcb\xaa\x0fI\x8f'
        b'U*\xb8\xc97\xcb\xbawpLJ9\xef\x98\x82\xe3\x0c!\xdc\xe8\xa2\x1f`\x0c\xcf\x1d\xbb\x00\x9b\x99\xd0LY\x1cX\xb2\x9b\xaf+\xe6\x0e\x92Q\xc1rh\x84b\xda\xcf]\x00m\xeb\x9f3\xa3\x9evS\xa0P\x8a\x10'
        b'\xd7\xcfB\x01\xfdr\xeb\xada\x8f\xae\xf4\xfd\xf98eh/\x9aO@\x893\x9b<\xe4&\x86W29\x93f\x87\x98 \xa7\xd5\xd8\xc6RLqL\xf2\xe5\x9b\xf2\xcf\x14\xe0\xd9!2e\xa5%M0%W\xd0\xa3\n'
        b'7\xa6\xd1\x17}\x9e\xe0K\xc19\xcb/d\xec\xea\xff\xae\xd1\xb4\x82\xc4\xd7\x16x\xdb\xd4gY\xa2\xb9\xa5_e\xd7\x03\x16\xf6EOw\xd3\xcb\xe4\x9d\x95\xab\xaa\xa8\x11r\xa0M/\xf3\x82\xa6\r<\\f\xcbI\x81\x06'
        b'\xf7\xee\xcf\x02\xabme6\xfb )\xb6_Pr~\xb0\xdaJ\xcf\x83\xc5\x91\x84\xd2W\xd7$g\x84\x8e\x1b\x1f&\x12Y\x9e\x87Uc\xb9\t\xb5\x0c\x9eh\xb8\x98\x1e\x9c\xbb\xe2\r \xfe\x13\x8b\xb0f\xf6\xc8\xa5\x1f\xc5'
        b'\x87=\xda]\x8e\x8f\xcb\xf2\x01\xdc\xfd\xa4\xc7;~yu\x8f\x91w\x08b\xb7\xda&Lw\xd3\x8d\xfb\xd7\x0e\x01ML\xd6\xbe\x87V}\xda\xf1\xcd\x18\xcb\xbf\xf3\xc1\xe3\xff(>\xb3\xb3\x11\x9dxQsr\xads\xf7\x83'
        b"5\x96\xc8[\x16\xfe\xc9\x88\x8b\xe6{\xa1\xcdz\x1b\x1f7>\x03\x12\xdaR\x1d\xbe\xea\x06\x1eZ\x12&\x80)M\x12a\x86-\xfc\x96\xf4\xa5\x04C6\xaf\xf3\x9eQ\x1c'\xc9q9\xf0\xae\xc9\xa6\xb6\xd9\xa1q5\x1bm"
        b'\xa9\xe1l\xb7s\x13\xb5\xca\xa8\xfb\x0e&\xa6*\x94\xdb\x94\x82\xb7\x8dI5\xe4\x81\xa6\x03\x0enRp\xe8\xac!\xccyNY\rF\xa4\xa0\x10\r)\x04\x8fW\xf7\x1f$\x82@\x19@\x83\xd0\x92\xb9\x9f\xf6\x05\\\x1d:'
        b'$\xcb\xe7\xba\xa6\x0b\x87\xd6\xf8\x8d\xb8\x84%\x89\xf35\xb0i\xb8\x84%\r\xce\x0b\x10\x08\x95H%\xa6\xec\xd1\x0cg\xe6\xb6s\xf7\xa5\xc9\x07Z\x1a#\xf5 \xef\xc37X8R\xb3\x1f\xfbL$h\xc8-\xc6\x9e\x08w'
        b'\xea\xc8\xe4-\x86,y\xa1\xa7\xc1\xdd\xafx\xa1\xaa\x01\x03\x95r\xfbx\xbbq,\x9c\x88\xd3B\x13\xa2\xc3YVt\x9fUP+C\xab\xe3\xb1\xa4\x86\x1d\xcc\x18\r:\x9c*\xdcg\x9f\xfc\xd1\x90\xb7\xdc_\x7fu\t\xb1'
        b'"v\x93\x80\x83\xec\xc8\xb1\xb3]w\x11M\xd7J\x08\x82_#\xa4\x1b_\xa6\xadq(\x85l\xa6\xe1\xe4\xa0\xdf\xc1XR\x9f&\x82<H\xcaW\xb8\x8b\x8a\x08!\x1f\x14#m\xad\xcco\xd1\xeb\xe3"q\xc5\xd2\x92B'
        b'\xf8\xb4\xe7\x16\x19\x00i\xb3\xca\x94X\xe1&\xd0\xa4,\x8f7\x0e\x8c\xd5Q\x9f\xcf\x9d\xc9 \x8b\xc4\xa2`A\x02\x7fR\x03\xa9\xf6\x02|`\xb2/B\xd8\xd4,\x05\xf2|\xf5UR\xad\x92=\xef\xa8\x85\xeeF\xe8p\x9a'
        b'\xe0\x97I\xef4\xbe\xa2\x108\x14\xc8\x12xw\xe5p\x8f\xb4\x83\xa3\xaf\xed.h\x00\x82S\xa8\x82\x9bO\xcc\xb0\xeb\xd1m\xd7yf\x94\x83\x97|\x01)\xcb\xd4\xf9\xd8\x1e\x13\xce"\x02\xfb\x08\xe9\xf8\x85\xa7\x81;\xc0\xd6'
        b"\x8bY#S\x07H\xb7\x9f\xce,\x99|\xbd\x11y\x85\xef\xbd\xf3\x9f\x05\xda\xa6\x89}`\xb1\x0fK\x02\x8aN\x94?Kmt\x00\xac\xdb\x1d'\xb9\xf6u\xb7\xd7\xc1\xa0\xf6\x8c\x9e\x15\xc9\xef\x82\x17\x1d\x01\x8b/A\x8e\xff"
        b']\x81\x17E\x82^\x9a\xcb&\x05\x11=.\xc5\x8b\x00\xd5\xca\xd9\n\x804\xad8\rB\xff\xc1~\xc6\xd3\xac<\xba*\xf9\xf0\xf4\xf0_\xcf\x90\x04X\x01p\x13\xc7C\x17Y\x18\xd88\x18\xe4\xa0%\x19\xf1\xe8.S\xfd'
        b'o\xe7\xb0d\x90\xf0\xc2\x1e\x86\x92\xa2h\x94JX\x94\x88;E\xfft\xb7}\xdc\x08\xdb+\xda<\xec\xe4\xb3\xc9j\x8c\x0c\xa7\xfeb\t\x13\x8b<\xbcSA\xc7\x9db\xaf\x0ce\x16\xf1\xb2\xfdK\\\xeag1\xd7=\xb0'
        b'W\xb0\xd0\x97\xa3\xac\xaf\xf0\xb0\xf9\xf7\x19\xc7M\x85\x1a[\x17\x0bB\x1e\xe9\x98X`0\xca\x97f\xa1\xf9\xf9\x92c\xf8\x05,\x81\xcb\x92ZG4\xf7\xf9\xfb\n\x95D\xbe\x17G\x97\xd7\xdb\x8dF\xa8^\x17\xe3\xb6\x16\xf1'
        b'\xcd\xf3\xbdG\x81\x90+{x\xe8\xdf\x1a\x12*\x99)$e\x84\xa3\xb4\x07\x17\xd5m\x92*rB\x13w\xfcp\x0f\x9aG?\x1f,b~~\x80\x14b\x87r\x0c\xda\x97\x16\xa8\x7fj\x84QX\t\xca\xca\x8b\xcb\x9c\xdb'
        b'\xd9\x11\xe8\xfd\xc0TIq$il\x8aEc\xf2\x92\xc6\xa2\xcd\xf0N\xf6v\xda\xf7$=i\xe3kp=l1\x9aJ&\x01wD\x92\x04\xbf\xc2\xd8:-\xe6\x96\xe0\xd1r\xf5\xa46\xd7\t\r\xd8\xac?=\x17\xd6'
        b'\xe5n|~\x84\x80\x0b\x8b_\xfb\xc93\x9a7SR\xd2\x8a}\x1d\xf5t\xf7\x08\xc2\x88\xfd\xae\xb3\x94"\xdaf\x94\x8b\xd0\xce\xb7X\xd9\xffW\xc7k\x0c7\xe8:\xa6y\x038\x82\x85("\xc7?\xfd\xc4\x07\x03\xa2\x1a'
        b"\xdfP\xe0BN\xfe\x92Zx\x12q\x083\x0e\r\x8b\x06\x04\xe4^ua\x80[\x82%\x9b2\x1a\x8c\x8fi\xb5(O\xa0\x83t\xf4\xd9zt\x95,\xa3\x98\xf4i\xe3\x8f\xf4\x7fy'\x85x\xaa\xa20\xde\xc2\xbbPN"
        b'\xf6\xaa\x1c\x86\x03\x08LJ7\xd1\x08|j\xe0L\xb0\xf5\x81\xea\x83\x99\x00c[\x8d\x1c\x9b\xd9a\xf8\xe5\xb6X?\xa6G\xe6\xcf\xf8\xcd9\x92\x92\x10}\xfc\xa4c/+\xe4\xa6\xc4\xed\x9f\x8e\xa2\x07\x15\x88\\Y\xc1r'
        b"{B\xb9\xf8I\x98\x11&\xd1\x0f\xcep\xad'\xe4S\x08\xa1\x08\xbb\xafh\x88m\x8c\x88 ,yG\x1c\xbccu\x9c\xab]\xc5#\x8a\x15\xcd]=5\x13EJ8@X\x7f\x1aC\xed\x94w\xd4\x8aRk\xf0$r"
        b'0\x9c\xf1?\xc9\x03\xefy\xdf\xbaex\x87\x80\xb3\xffO\xbct\x08\x17FW\xf9*\xb3\x12\x03B\xd6\xecfQ\xd7!\xc5bu\x9e\x7f\xad\xb1!\x1a_\xbb\xd0F\xff\xbf\x88\xaa@\x92 \xc0\xf3\xbb\x91p\xb3\xb6J`'
        b'\x17\x12\xadS\x8c) $*\xe6\xee\xdbN\x12\x8e\x01z\x80uUW\xee\xa7\x8d\xa1k*\xe5\xf8\xc4\xbc\x9e\x971N\xca\xa9{iO\x84as\x8b.\x04\xbf\n\x88\x91\xb3\xfb\xbbO\xd1S\x81\xed\xe2\xa9\xbb\xea\xbd\xb7'
        b'f\xb7\x83\x85$\x0e\x0b\xb8"4\x19\xea\x06\x04\x06hlD\x8e\xd8\x95\xd3\x92E\xde\x07M\xd7\x91\xc70\x82\x04\xf1\xc8\xc0\xf4\x88\xa6T\xa8\tbh\xaf\xaf\x82\xf9\x81{I\xc1\xc6\xbe\xda+\xa7\xef\t\xe6T!\xfa\xaf'
        b'\x82\xe8\\\x83^G\xff\xb2bw\xf4\x82\xf9B\x83fMH\x83W\x87\x17\xe8\xea\x0e\x0c\x83,\xa7\x08\xcd\xb2\x94@\r\xd4\xd9\xb07;\xbe\xf9\xd6\x8d\x81Rd\xd5:\x18@A\xc0\ny\xb5\xa3c\x07\xe5=\xe1.^'
        b'\xb7\xd2\r\xcc;\xf5\x02\xdb\x15q\x82\xe0\n\x9f\xcc8\xe7\xa8\xe3\x1a\xa0Q\xf8#\xc1\xa3\x121\xab\xc3\xa3w\xd9\xbb\x1c?\xba\xac\xe8\xe7\x1b\xc7\x18\xd5\xf7\xf3\xb74\xf9^v\x81P\x02\x1a\xf2\x102\xe1~\\\x10\x07\xe6'
        b"\x91\x0b2\xb1\xdd\x95\x8a\xf0!P\xd3\x8d\xf5\x16\xd2\xa3F\xf1\xc6\xfb\x7fP\xd3\xbc\x19\x90E\x08\xd6W\xd8}\xe1c5\x89\xcb\x84vW'\xbb\xda\xf0\x88\x94~\x95\x15\xbc\x1b\xa8\xc6\x98\xaf\x02\xa6\xfc\x0e\x00\xa7\xb9CB"
        b"\xeb\xf3-5\xe5-\x813/\xc3\xe9\x86]\xa9t\xa3m\xee\xc6\xc3\x88B\x03Ph\xd2\x8d\x84SC\x7fw\x04\x99\xba\x04\xe6'Y\x9c\x81\x05\x1f@a\x87\xd7\xac\x15*\x9d\x19V\x03\xcdM\xf06\xb3\x15\xc9\x10\x97\xbc"
        b'\xa3\x85\xac\x18J\xc63\x86]a\xcd\r\xab\x98\xa5\xf9\t\xcc\xd78\xc7\x9f\x01\xc58\xde\x8d\xcd\xf1\xf8A\xde_\xc2\xc7\xcf\x8d\x1bz\xb9\xe4N\xe0\xdc\xe4\x1e[\xc1\xd5\x17\xd1B\xa5\x1f=,$C\xa5A\xd6o\xf0b'
        b'\xc0\x1b\xce%\xec\xba\x9ap\xdd\x9f\x94\xd8\xa4\xcf1\xdf\x0e\x95\x11\t]\xa2:\x8e~O\x8c\xf7\xe3\x1c\rpEG\x14~\x8d7\xd8*x\xdb\x9f\xf7\x18\x91O\xdb\x0cM\x1dl\xae~\x8d\x96Gjtw2\x1e\xe7\x8b'
        b'\xe3\x06\xf7?\x93\xffR\xe3|\xc6\x17\xd0\xd7U~\x01\xee\xc1\xa5 ?\x01\xd6\xd6>\xf0\xcb\xdf\xf1\xad,\x07\xd0o\xd6$+\r4\xddD\x03r\x95\x8et\xa2\xc2\xd4\xc5R\xb4\xe4\x80\x14\xd2\xc9p\x0c7\xd5\x8e\xf2\xeb'
        b'\xd2?\\\xd2C\xe6\xbe\xfc&\xf3\x89\xc0\xe4\x15\x01v\xb5\xe4\x96ex3\x86\xbf@dD\xad\x8f\xd2\xcc\xb5lF\xd8\x06,\x82\x06\x18p\x03\xa0Y\xd6\x90\x8f\x8b\xca\xf9y\xdf\x9f\x06\xf2j\x04\x1eq[\x10\xb6H\xfa'
        b'E\x84E\xde\xb5\xac\xa8\xd37\xd4}\xee\xecv\xa1\xc1\x82*\xdfs4jA\x08"\xee\xe0~\xe3B"\xf6\xd6\x9bQ\xa7\xb6C4\xea\x86\x9c\x83,\x8a\xf8V\x03\x0f\xd8\r\xf4m\xaf9\xf5\xb0]\x8c\xea\x02e\x97\xc2'
        b"k\x06\xf1LE\xe4\x92\xbc,\xce\xcc\xe5/\xa8\xc3\x00\x9f\x17\xb3\x12\xc0\x7f\xb2\xcdff\xf8t\xd2\x94\xf8\xe0\xa5\xd8B#\xd1{d\xfa\xe4\x0cX\xc0\x95\x12&I\x839\x00f\xfe\xad\x8d'b\x9a\xaa1\xd7bo\x94"
        b"H\xa1Xy\x93N\xaf5\xbb\xb7\x0f\xba\xf7\xc2\x14'\xee&N\x13\xf5z cU\xfb\xdan\xac\xf9*\x89\xfa\xcfr\xf7L9\xd8]e\x16\xa9\xca\x16\xd8N{\x13\xde\x036\x95n\xf24\xe0W\xef\x15\x1a*\xb7\xec"
        b'\x7fW8}).Z\xbeR5s\x89\rF-v\x7fsb\x83\x1fb\x0e\x95\t>\t\xb0i\rqH\x9eB|\x1c\x1f\xc2-gZ\xf3TY\xce\\\xe2R:\xc9\xe7\xa9\r\xe2\x1f|[\x83*\xae\xc7\x94\xf5\xe9'
        b'\x7f#c|C\x01T$\xf6\xfe\xae\r"1\xbd\xf2\xa48OJ\xc4\xfd]/\xb4\xceR\xacJE:x\x88S<\xeb^\xf6\xd3q\xe8\x00\xe8\xd0\xe2v@\tn:I\xb2\xde\xdf\x08f\xd5\x83\xdac\x86\xb1mk'
        b"\x03\xaa\xdeT\xe2\x9a\x95\x8a\xe8VXs/\x81\xf8\xdc\x9a'\x8f\xadr\xe6`\xce\xb9\x9e\x9b[\\\x19/\x9f\x86M#E\xd2\x00\x12\xe4\xa2H)\xc3\xef@G\x05R\xc5\xd4T\xe5\xa7\x0e\xa6\n\xb8v@FQ\xc1k"
        b'\xfb\x83\xff=\xe2\x93\xd5\xb9\xcc\x88\x0c\xdc\x08\xd4A\xc4\x07\xcd\xb7\xb2\xaf\xae7\x9b\xc7\xd9M+\xff;\xf1ny\x96\x1f\x9f\x10\x9f\x1829\xee\xa50F\x189\x08\xb8\xa1\x13\x18\xb3\xb8\x81\xdf\xad\xcd!Vk-\xbd\x14'
        b'J\nx|\x86\xa1\x0b\xca\x90e+P\x97\xaez\x15 U\xf6\x12\x0ekyN\x81,\r\xfd\xea\xb7\x0b\xf0_\xbe\xd8*\xfa\n\x17\xf7\xb7P\x9c\xb5fP\\\x14\xea\xb0\x15$s\xe33\x0bF\x8dV\x87 \x123\xb8'
        b'\xe5\xa8\xa8s\xc7\xf8tV\xb3GQ\xc2\x1c^\x0b@\xcd\xbd\x18X\x85n\rb"\xed\xda\xe2\xc5\xdd\xc3\xf4u\xd6tk\xc1\x16\\\xd6\xabQ`}\x80k\x07\xa1\'\x8b\xc1\x80\x1a5\x10\x0c\x0f\xf5"\x04\xf5 \xbe\xe8'
        b'\\\xf5~\xd0g\xaft\xfa\xffv)\x9f\xcdk\xf0{\x9c\xb6\xe4G\x916\x80G\xef\xf6\x05\x9fg\xd4\x90b\xfbo.\xc3\x88\xbf\xe2F\xbb\xb0\xe8\x08\x8eU\x0b\xeb\xdf\x1d@\xb10\xaen\xc6\x8d\x02A\x95\x1f+}\xaf'
        b"\xb4)j7@\x91\xe7\n\xf1\xb1\x8f\xd7+\xec\xb9\xbdKx\xc7\x96\xba\x97\x97\x00\x89\xcag\xeer\xa6Sg\xd53;\xb0\x96\xac\xa05\xf0t\xf3\xad\xe1f'\x18\x9c\xa1w\xc1\xf6\x8f\xe7\x16\x1a\x12\x05\xdd\x0b!+\x8e"
        b"bsO\xc2iH\xce\xf8\xd1^\xea\xea\xd0yGa\t$\xe7\xc3;\x18@\xb8\xbe\x1bH\xa4\xd5U.\xe9w\x1by\xb0\xc7\x11*\xd49'\x16\x07\x8fLq8O\x7f1\x9e\x9f\xac\xa5\x80\xa4^5\x93\xe1[\x8eY"
        b'\x9b\x8b\x9a\x1e\x84\x07/\x89\xff\xa81\x1c\xf5\xd6j+\xb2W\x1f\xb9\xb9u\xd5l\x01~KaWunT\xfd\xbc\xe7\x9f\r\x84\xa8\x94\xbd\xa1g ,\x89\xa1\xc19\x16/\xa0\xb0\xa3\x97\x00&<js\xa8y\xcd\xbb'
        b'\x7f\x12A:dPN\x8caQ\xed\xc55\xaa\xd1\xe3Q\x13\x9f\x8c\xf7\xc2\x9d\xa3\x9a\x04w\x12\x04\xe2\xca%\xba5\xe4h\xd9d\xc8\x01=\x10\xc3A\x92<%\xee\xd0\x18Gb\xac]"\xd2z\xa1\xbd \xc1K,\xc7'
        b'\xbb\xcb\x0b\xfc*\xee\x91_\xc2\xa5\xefv\xdd\xae2\xdf\xa3e\xe9\xe8\xe9<\x80)v\xf3P\xb8\x9f\x82\xb8\xc7\x1b\x12\xfb\x8b\xe1iN\xa4\x01F+\x91\xbe!"7fu\xba\'(#g\x9b6\xf7\x9f\x1e\xc8\t\x14,'
        b'\xeb\x18,\x03\x17\xf3\x01\x97k)\xee\xb0\x8fE\xb8M\xac"\xc0\xd8\n/\xe9(\xc4\x80\x9a\xc6\x95Y\x986q]\nC\x82B\xe5\x85\x16\xf75oi\xd2\xc8{\xc9T\x9fmuy\r\x8c\x10W\x85fx\xeb\xc84'
        b'\x966\xd01\xb4B\xcc\xb8\x80]S\xc8\xb3\x1a\x8ag\x8d?\x91\t\xa4\xd5\n\x08{\x88\xef{\x05\xeaC\x95\xf0%\xb9z\x0f\xcb\x94I\xb7\xa5\x0b:\r\x0ft=5FM\\\xb42E\x05T\xb8\xe3\x9cq\x1b\xb0t'
        b'\xbb\xf8\xa8\xa5\xd7a\xe6\xf2\xbe\x10X\xd3t&\x8axR\xb0$cv\xd4\xa8\x1f`.\xe4`<L\xa4{$\x81\xba6\x7f\xaa1>\x99/\xf0\x1f\x99L\x06\x12|(\xae\xd25\xf4\xe6\xf2N\x99\xca\x92\xd5\xbf4\xb0'
        b"\xb8c\xc4\x9aLi\xada\xb3\xc0\xaa\xefj\xcc\xc3=\xa4d=B\xa3\xd0\xe7\xcd\x15\xeb\t\xf0\x89>GY\xdbx\xa1z\xe7\xe9\xff\xbc~\x1b)\xfb\x18Vxo\xe3A\x8b'f.\xb2vRv*c,<\x85\x1f"
        b'\xdeKZFjR\x0f}*\xdc\x9bG\x086\x95:}%\x84=~\x12\x9d\xe0\xcb\x82\xf3\x14A\x17\x83\xc6\xee\xb4T\xcb\xcf\xcb:\xc6\xf5\x90\x8ds\x03\x0e\x19\xc3r8\xdd\x0eh\xd8\xb1\xe5\x04rsAkD\x08R'
        b"\xc0k\xa3\x13F\xde!'\x1d\x87\x8d\xdb\x18\x84t\xf5\x00\xaf\xea\r\x1a.\xf2\xbc9\x85Z\x0e}z\xf1\xdeq\x01\xb3\x1d\xdah\x91\xdc\xac\x1a\x9d\x8ar\xa5\xac1\xc5J\xe0\xbd\x04\xe5\xf7m\xb8<_\xf6X\x92<i"
        b'\x8cs\xd9\xb9\x18\xc4\x15\x17\xc3\'\xce\xc2\xa7\xa2\x88\xd1\x87\xef\xa9\xeck\xd8\x88X\xa7\xd0\xb3zj\x1e\x17sF\xd4\xc2\x006\x94\xe1\xbet\x97\x05\x1f\x96\x1a\xfc\x1c\xf2z\xf4~D\x9c\x85"\x08@\x9c\x8d\xbc\xa2\x99\x17'
        b'\x0cu6\x8b\x07\x95\xe1\xb1v\x04\x06\xd1\x82J:=\xf1\x0f|F\x81\x14}\x92\xcd~\x01RX\xdd\xa7\xf2\xfe\x17\to\x82M\x8c5P\x07|;\x1c\xdb\x13\xc1H\xcb\x95\xdcHe6Bq\x1cp1f2\xcc\x85'
        b'\xfe\xa9\xadn4\xf2}a\xdeQ%\xce\xd6\xc03\x10\xb2\xc1Y\xd5\xd1\x02\xb6\xbe\x12\xb9VC\x15\x11\xc5\xd7E\x8a$\xf95\xf8;!\xfcB\xd3\x90\x16\xcc?\xa9|\xf0\xa4\t\xbe\x19s\xf6 h\xad\x11%\xad\x84A'
        b'\xf6\xa7\xe4o\nd\xdf\x08\x05+\x1f\xd6\xfapK[[\xe4H\x1c\xd8\xd5\x9f\x8c\xaf\xb6\x9b\x92\xe0\xcf\x07\xf3\xb8\xf3\\S\xcb\xe2\xa6\xac\xc5g,\x9d$\x9e\xe4\xfe\xc5\x94X\x00G\xfdx\xc1\x1f\xb9\n\x0e\xf2\x8c\x98B'
        b"\xabAH\x7f\x8c\xdb6#\xd9\x06$\xa0\xf8{n\xef\xa5\xab\xac%\x12\x90\xabW'[|?'\xac>[8p\xb1~\x97\x92q>\x0f\xb1\xc1\x03\xc2)3FX\x19C:|Z\xbc\x85v\x91X_\xbe\xe8U\x9b"
        b'\x85%\x866w\xde"a\x0e|\tH\xe5\xedR\xe7\xb7\xf4\x83f\x97WS^ml7O8\x81\xf9\xec\x87e~\x0e\xd0\xef\x151\xb7 fGBmp\x95I\xdbJ\xb3\xf9\xd5\xe6\xf3%\x91d?\x05\x9d\xb6\x82'
        b'q\xdb\xe3\xdd\x85A\xd4\x9e\xd9J\x7fSNuQ\x9c\xfe\x14=1\xd4\x99_\xdf\xc1K\xfd\xbc\x8fQ\xb2\x95Y\xb5\x001[\x11!Y\x9e4:c\xdf\xdd\xcdEYs7\x91eAj\x1a\xa4\xdf\xa6-:\xe7\xeb\x0e'
        b'K\xbc\xa4a)\x12\xba\xe6\xb2\xec\xa1\x02\x83\xda)\x8eD,J&p\xa2\xaaQO(\x19J\xe2\x11\x90#\xf3\x10\xef\x89\xca\xad\x85u\xdd\x88;\xb0\xf5\xb7R\xae\xbd\x92\xc1\xf0\x9f7\x82\xc8PI5\x80\xb6\x89\x9b\xe9'
        b'\x1e\xbeCf\x19\x89\x06,\x1a\xb6\xb8\xdcf\x16\xbf\xc3\xb8U\x8b\x8a\xfb\xc3\xa0\xf4\x18w\xcex\x16\x81L< \x17\x87\x00\x0b\xc724\x85@\x86I\xf3!\xd1\x93\x92\x85\xccr\xdf\xc2\x88]\xb2I#\x0cs\xe2\xfa\x11'
        b'\xcd\xfc"\x1e1\xc5\x82\x7f\x84n R!Ur\x88\x14\t\x7f\x81Lw`\x08Q\xab\xaf\x88\x94\x1b\x86\xe6\xb6\xa9\x97\x7f\x19>\xf5\x8f\xc8\\o\xf8\xf1\xbe;\x95\xcb@\xab\x92~j\xab\x81\x06\x9f\x9dL\x17\xd3/\x06'
        b'h|8x\xd2\x8f\x8f\xf0g\xb2Y\xc2i~\xe9\xa9\x96\x9d \x1b\n\x93\xe2o\xe1\x84\x1crn\xe8M<\x06\xa5\x15\xb7,\xf9\xc2\xb6\x0cF9n"\x05 \x94\x1b^\xd3\xa1iN\xb4\x12Z\x06\x0c,>\x81\xfc\xa1'
        b'\xff\xb5\x04\xd1\xcf\xd27\xe9R\xbb\x9b\x8c\x87\x92A\x8b\xfb3[\xcd\xd2\x9bm{\xdb_a\xf6\x9c\xe4D\xd7\xb6W\xa0\xf5\xc2x?\x80\xff\xce@`cT\xc5\xea\xdf9\xa4\xc1\xf7\x9a\xb7\xa6P\xbb#\x9a\xd6\x83\xe2\xd2'
        b'\xc38jC\xef\x16Q;\xcd@\xb3\xd3\xed\xff\xdd\xf9?5\xc6\xfc\xb1nE3/\xaeciB\x93\xa3\xbeg\xf0\x19Q/q\x91SAH\x9f\xbe<h#M\xc0\xf4\x02U-<,t\xbd\xc7\xbb\x98}\xf0\xb62'
        b'\x1dhT\xb33\x1a\xe1\x19\x0b\x10~\xc7\x8b\xd6\xcd\t8\xe0\xf3\x01\x02\xdb;77\xf9\xb2\xbb\xc7\xc2\x90\xf9@\xbb\xa8\xf25E3\xb5yB\x04\x10^\x9f\x96\xea\xafL\xcf\x088\xc8\x02\x06\xae\xcd\x91\x97\xfa\xe6\xc6\x9e'
        b'7\x1fsL\xac\xad\xe2\xb4\xe0\x14\xb3\xc4\xca\x16w*\r\x1d"\xac\xcb\xb3\xe9\xb4j\xd8\x80\xf6\x97BK\xdf<>\x01\xc2)#Wt:3\x0eJs\xbd{\x95Q\xd1y\xdb\x1a\x01)M\xc5\x07w\xea\xcf\xc5ro'
        b"\nM,\xb3\x91\xb0\no\x96N\xd8\xcfB\xf7y\x90'sQ\xcc\xad\x01}\x94`\xb3\xfegH\xdb\xf7\x89(\xa3*\xf3\xe2\xe1\xf9\x9b\x80\x05\x86\xa2$\xa3\rD\xd8;8\x18se\x85@,Q\xd7\x01 \xe4\x90\xbc"
        b'tz\x8c\x12\x04\xbd\xb9\xe9\xefa\x84D<9F\x940NH\x1bm\xf2\x04&\x12S9\xacPYb\x94\x16\xe5\x00\xd50\xd9\xfe\x14v\x9d\x16\x95\x06!C\xea\xd7\x19\x8aUA\x1d\xd2-9\xd8\xb2E\xe9\x01\x00\x00'
        b'\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa'
        b'\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
