
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsT.\x00\x00PYARMOR\x00\x00\x03\x07\x00B\r\r\n\t0\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x14.\x00\x00\x00\x00\x00\x00`0\xfb\xf0:\xd4HV:\x07\x9c\x1d\xd0\xdd\xff\xf4\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf2\x8f\x02\x1eE\xf1'
        b'\xfa,A\xaf\x82^`9\x84\xb8\xe7k\x84\x95\xfc\x0c\x03C\xde\x81\xcdVE}zM\xd5hB\x80\x85\xf1\xea\xbf\xdb\x98d\x123A\x0f+\xda\xb2\xbaqF\xa2\xd0Q\xf2f\xd6\\\xc8\xedG\xce4\xbc\xfb\xbeVi'
        b'Y\x8c\xfb\x81\x1e\x93G\xcd\x1c1\xb1\xf6\x84N)\x0f\x8c\x97\xdf?\xc2(\xd6\xc7\xbe\xab\xc9\xce,\xe6u\xf0\xf4\xf3\xc0\xd9tw#\r\x91_D\x988\xf9S\xac8B\r\x04\xdco\xd1.x\xceoJNI\xd5\x8d'
        b'\x82\xe49.:\x86q=\xc56\x8c\xb9\x9dx\xf1\x8e\xeb\xec\x13>\xe1WH\x83\xa91\xc0\xcd4\xef\xcf\x15F\x8ct\xb99\xcc\\}N\xfd\xe1&\xbb\xb8[H\x95\x82\xfd\xe5\x7f\x8b\x94\xc4\xfb\xcf\xe9\x132\x8f\t\x11'
        b'v]s\x18\xedBA\xe2E\x15Z\x80\x98\x91\xee\xc4~\x1a,\xbcn\x15\xac\xab\x0c!\xe6m\xf4z\xb9!\xe4Q\x10\xd1"\xac\xe9\x9cW\x99\x899\xca\x97\x0e\xb4\xd2\x0f\xb09WiO\xcer\x8c\xe8\x931\x07c\x9b'
        b'j2U\xb8b\xf0DU\xba\xcb\t\xd9H;\x82&;\xb2\x1f\xffr\xcc1\xdf\xdb\xa6\xdfh\xfe\xb6\xb3\xed\xc6Y\xe1\xb8@\xe9\xde\x01P\x8a\x042\x06\x98\x0c\x95\xbe\x9cF\xe6c\x14&i_CB{\x1e\x89L\xb0'
        b'\x01\x177\x0ca\xea\xa7\xf0\xb6\xab@\x90pnl%>(\x93\x0c|\xc2#G\x86\xf4\xae\x1a \xa4x\xae*\xb7\xdd\x88\xe1A\xfc#\xf9\x0c\xc4\x8a7\x00\x7f\x0c\x85\x11\xbd0dx\xf6;77+\xbc/\x14\xef\xfe'
        b'\xcf;\xfdB\xe3\x94\x94\xfbu\x96\x9b\x91\xabr>\xe7m\x05\xa0\x923\xf1Z\xa7\x8e\xce\x1b\x00\xe7\xfet7\xd9\xf1r\xf9\x8e\xde\xec \x80\x08\x13e\xb3\x10\x07\x13\xab*\x84z\xd7\xde.\xefC\xc6\r\xee\x16t\xcd\xde'
        b'\xb6\x16\x1d\xc1\x95\xfa.6\xd4\xe5\x15.y\x9d\x95Qh\x14\xb4\x18\x80 \xf2\x8a\xcb\xcfL2j5[\x1e\xbe\xe6/\xab\xeb\x8dYXh\x18\x01\xd8\x97\x15C\x05\x01p\xb0\xb5nI\xc9\xe6\xc3\x81\xba\xbb\x89\xb6lQ'
        b'\xbf\xbf\x99k\x8a\xfb\x8d\x9d\xc2b\x7f \xab\xac\\\x82\x90\xfb\xd0\x8c\t06\x80y\xdd\xcb</\x1fb\x07Ai\x90\x8e^`\x1f\x9d\x13;W8R\xaaA\x90$4\x05\x83\xfe<\xdc\xab9\xccNaE\xafr\xf3'
        b'4o\xa2\x01^\xde\xe3\x0cg\r\xccz\xb3\xa7\xd9\xdd1\xfd\xf6NJ\x97\x8e\x0b6\x8d&\xa0\xfa=o\xb0\xa4\xc6\x84\t,\x8d\x96\xa9\x89\xa1FtGi\x9c\xe8i\xa5\xc9bX@\x08\xfeQ\x06wN&\xfccK'
        b'\x8dm\x96\xee$\x1d\xceqd\x1f\xb9t\xe0n\xf7\x1a\xfd\xc14\xa4\xc2\xc3fLF\xb3\xbff\xe9q}\xe4(\xcad\xb1\xc9\x88\x1a\xd2\xfdi\x8d\xb9\r9\xfe\xd4\xc7Q^\xf0S\x13O\x947\x0b\xe7\xb0\x83Z#\t'
        b'\xe0\x1byl\x90\xa0O\x84q6`\xba\xef.1>q\xad\x8es\xd3\xcc\xd7\xa7\x9d|Y\xcdG<X\x93\xd1\x1e\xf9\xd3Ha\xf2\x08\xf0u\x07\xc6\x03\xd3^6p\xa6]{P\x85\xdf\x87\xea\x84Y\xa2\xb7w5/'
        b'1\x9e\xb7\x0c\xde\xf0\x10@\xe5\x02\xdc\x1f\xd2/\xc7\xac\xeaJ\xb7T\xa3[\xb7/iU\xbe\xf3k\x94Y\x98+\xc5P\n\xfdL<9\x8f\xd2\x059g3F\xdev\xe3W.\xae\xe1\x1b\xf1\xa3Ta\xe1\xdc\x08BK'
        b"'>\xef\x14?'\x12#\xa6\xafZ\xab\xee_\x12d\x18Y\xec=\xed\xc3\x98\xf6]r\xeb\xb4\x0c\x19\x92.z\xf5*\x19!\x8c\xce\xee\xf4\xc9H\xf4\xc2\xa7n\x12\xe9\x92\x94n@\x86*Gg\xf9\x8bh\xebn\r\x01"
        b"\xd3\x8d\xd6_\xa7\x19:_\xd4\xf1\xd7\x01\xb5Z\xf2b8\x04hg\x08\xef\xe9\xf8\xd5^\xc8e\xe2D\xec\xd2ra\xf5\x10\xf6\x9c\x15\xe3\xff?K\x92\x95\xbbT'\xad\xbd\xb2\x1f2\x83\x85l:\xa2\x96%\xb5\xf9=\xf4"
        b'3\x1d\xbb\x08K\xad_\xa1vd\xb2g\xf7J\x98L\xdaNw4\n\xa8i\x06J\xa6\x123 \x00\x07\x0f\xac\xfb~\xba\x93b\x1e\xe9\xe5)\x05\xfad\xf5J\xff\xfc\xad\xba\xc1\xf8\x03B\x94\xdfD\xa6\x8f\xfe\xdb\xd0\xd4'
        b'\x88\xba\x83->\x87\xc8\x86KbO\xa0\x81\x1bx@\xa9BZ\xc5Y\xf0\\\x19\xaa\xe0\xbe&@\x07\xd2\xda\xa0c\x7fJ\x8e\xd6\xb8\xb4\xd8r;/\x17%(\x94\xac*\xce\xd7\xfe\xa6\x90J\x88F\x1dB\xbc9\x95\xd7'
        b'\x04?\x91\x8e\x1etB=f\x91\xe6>\x18H\xedF\xec$\xd8\xe4c0\x9bv\x1dp\xcdK\xdeh\xd3\xff\xe1\x13\x05\x9c6\xa7\xb4i\xd9\xa8\x15o\xb6m^\x0f83k\r\x94=:;C\x81Z\xaa\x8a\x83\x9c\xcd'
        b'b\x99.\x91\x18\xfb\x8f\xbb\xfa#\x9a-\x1arR\xd7\xe2g\x98\x18L\xbd\xa6\xb0xY\xc3\x85\xc2\x80\xd5x\xcd\xa7+?\x0f\xf2SdGKs\xd5\xd9\xf5\xd8\xc1\x9a\x82\xf2\x10\xc8F?\xf8/\x8b\x96O\x9c\xe5\xfdw'
        b'\x16\x18|3\x16\xeb\xb7\x9d\x83\xbf\xe1\xf6A\x07R*\xdc\x15\xeb\x04\xbd^am\xd7\xc2A<\x1e\t\xfc\x00\xf6S\x02\xb7\xce\xec\x1a \x03\xd8\x84\xa9y\xe5\x93!\xe7\x90Wj\xcd?/\xc2B\x07\xcc\xbf\x83x\xbf;'
        b'\x9d\xf5\xec\xf1\xab\xb8\xf3\xc8 \xfay\xdd\x1b\x8aJ\xe7r\x05\x7fO\xff\x19\xea\xd2R\x8a\n \x9d\xbc\x8a\xdbV10\xbf\xf4\x18\x04\xf0\xc5}|\xc9\xb8\xe8\xe6,\x86-\x06\xb0N\xfdjN*Q;(\x94\x0f\x90\x12'
        b'\xeah\xda\\\xd5z\x88\x18\xcb\xa8]\xbfn\x7f\x07\xc7\xe5Qi)\xb0)z\n\xdc\xbc\xc3\xdb\x95e\x80\x1d8r\x02\xa1\xf8.\x86\n\x83\x99\xa8\xd5<\xe6\x9e\x86\xcf\x9e\x8a\xe1K.<\xa9%sB\x84\x93\xe9\x88\xd7'
        b'\xf7\x00D)\xb1/\x9a%\xa1\x96\x02\x95\x9dW\x80s\xc3\xd9\x12\xe2\xa0\xf5!\xf3\xa8"x\xb5G2\x1dXTQ\xb3\x12\x8a\xde\xac\xb8w\x1b\xe5\x1c\xadj\x1f)\xd6\x0c\x92F\x84\x0c%\x8b\nL\xd8$vX\x99\xda'
        b'{\xb8\xcd\x13u\x80V%~Q\x10\x08,K\x8bDP\xf0\xb5\x97\x00`+\xdbg&\x13;P\x94\x06\xf8\xa6\xea\x92F\n\x7f\xd6\x1cp#\xdb\x08\x86\x99k\x8a\xc6t\x0b\xce4@ml4\x9f\xf4M\xbc\x8f\x19\xd9'
        b'\xa8\x97\x00h"#\xc5\xf1\x924\x19\xe8\x8b\xabr\x01\x1c\xa7\xd7\x96!\xe8\x1d\x84\x173\xae\x95\xc7G\xa2\x95\xa9\x045\xa7m\x12\xe52(\xc1v\xcdU\xc0\x82\xfa\x9c$Z\x86\x13\xa7<\x81\xdd\x8fT\\\xf1`\xc2\x1c'
        b'3\xe3\x16J\\\xc5]\xb0\xccW\x05\x9d\x91\xe2\x88\xccy\x10Q\x9c\xb95,\x85\x9f\x98\xc3\xfc\xfb~"n\x9d\xa5\xca\xbf\x1f\x7f\n\xe4\xf2\x1d\x17\xe5v\xe6\xaf\xcc\xd7\xc3\xcaB\x04\xc1XaMEp"\xb4\x02/\xc5'
        b"]e\xd8\xbbw\x9fN\x8bG\xad\xc4\xbb\x8b\x89\x1f&\x95m\xf8\x8d\x96\xfa\xaf\xda8?\xa1]7'\xbf\x04\xc2}\x9bk\x08\x84R\xf2\xc1\xed]N\xdb\xe7\x932(\xa7\xd4\xa8e\xc0eP\xc4\x84\x93A\x1e\x95u\xc5"
        b'\xfc\xa5\x13\xcd]\xb5\x8b)\x07\x86\xccnmy\x80\xadX\x90\x1b\xfb\x06\x8aoq\xcd\xb6\xe7\x15\xa0\xd9\x18\x18X\x81\xdbcA4\xceQ\xccB\xfc|\xb2LqD\x05\xd0\x0cu?\xf1e\xef.\x9e\xdc\x15\x94Q\xb0\xdf'
        b'\xb55\x8d>,,P\xec\x14\x98+\x95-\xedC\x85\xcfp|l\xa8\x8c\xa61B`\x06\xf5\xb2\xb4\xc5\x95\xb4e\xa0\t\xbd\x87\x90\x9d\xbb}\xc1\x15\x13\xed\xb2R\xab\xb8\x7f$\x99\x8c\xe4\xfd9Lf+\x81\x16\xb1\x84'
        b'\xd8\xad\xafhn\x16\xd7l\xac\xc4e\x7f>\xa8\xbe\xf9\x88\xb3\xd8\xfd\x10k\xf3\xc1\xd0b\x11L\xb1\xd8u_\xe5\xccU\xb4\xc9\x1f\xc5t\xd0\xd9\xed\xb5\xbe\x1e`\\qEz\x85\x92\x85\x99T\xc8:\xcb9\x1d\xc1C$'
        b'e\x1fGO\xc9l\xcf\xf8.3ETu\x14\xfb~\xac\x81I\xdeS\\\xc44\x83\x11\xe6\xad\x81{\x14\xb1\xf25D\x10\x8d\x04R4\xe6\xa1\xf8\xb1\x7fmv=r2C\xdd\xcf!\x02\xa1p0\x88"\x10 \x07\xeb'
        b',\xa6h\xe3\xeb\x88\xb0\xcf\xb3@\xabw\x9e\xa1\x13\xd0\x806\xb6\x17\xe8N\xf2\xaa\x9b\xa8w\x91\xb4-\xff\x13+\xc6x\xe2.\xa5v\xaa3\x03pV\xc5\x0c\x9an\x1c\x01)_4\xd7\xc6\x90\x07\xfb\x10`\x826\x92\x7f'
        b'\xe9\x86\x91C\xbf\xab\xca\xb1@b}l\x16\x1e6\x9dN\x8f\xeaf\xea\xf9\x7f\x83\xedK\x13\x131\xdf\x00\x0e\xcf\x18\x8b&\x1bp\x05C\xe1(0\x9be\xf9\x9eOJ\xber\x00\xf5c\xf4:\xfd\xfaAk${!\xbb'
        b'\xa5H\xc5)\xba\x1d\x85\xab\xbcH\x87\x16g\x81\xdc\xf4\xeaw\xea\xf5\xdfmd5\xca\rw\x06H\x98t\x83\xed\xa2\xc3XY\xff#\x05\x81\xed-\x0cby\x86\xde\xb3\x95\x86o>\x90\xddVk\xacN\x88\xe2d\xb7Z'
        b'\xb9\xc5\x84d\x7f\x9b\xfe"\x98\xce\xc0\xb4\xe1\x8f\xf9\x9a2x\xb3\xa1eQ\xb0iC\xb5o!\x97\xd8zzp\x8b|?E\t\xb1\xc7\xdfJ`\xd9\x7fB]\x03am\xf3\xca\x10U\xe3\x8c\xe4{\x8b\x8dU\xa9?\x18'
        b'\x8c\xb9W\xfe\xc0b\x9b\x91\x8cX\xcf~\xce\x04\xef\x04\x16\xe4\xde\'5w\xd7\xa6\xbcL\x10\x18j\x80a\x98\xb0e\x8d\x8cYx"6]\xd3\xf4\xc43=\xf1\xaf\xbb\xcf\xf7\xf9\xcc\x8e\x90HZ,C\xcen\x96\xb2\xb9'
        b'\x1eEa&\xddC\x9a\xece\xfe\xec\xfe\x89\xff\x9aG\x043\xd8>t\x10\xaaF\xea\xc2/\xee\xcbbZ?\x1f\x91D\x801m-\xcb\xdd\xda\xd0_>1\xc0v\xcd\x91\xab=%p\xfb\xc9\xd3M\xb8s\xe2PoL'
        b';I5\xa4\x9b\x1f\xc0\xfb.\x1b\x9f\x94;\x81\x14"\x1f?\xccD\x7f\xc1\x7f\xc5\xed3\xad\x7f\xd3\xf2\xa9\xf9W\x19Rq\xab\xf3\xa2\xfa\xda\xe8\xa8#\x01\x95\xbd\x9c\xe1\xb3I\x18\xf0\x97\xc2\x9dJ\r\xd3\x8a\x08A\x04b'
        b"[\xd3\x8al\x7f\xe2}\xec\xf0\x7f\xb9\xac\xa8\xc84\x0b\xa7U\xa5\xbc\xf8,\x0cR\x91T\xdc\xb2\x7f\xd9n\xcf\x94u\xd5G\xbe\xe1Z\xc5W\x15\xce\xe0\xf2?\x85\xa6\x98:q:\xce'^]{\xe7'\xe5\xf8\x18[\xca"
        b'\x8eL\x03s\xc01\x16\x84\xc88\x9f\xdfo!\xc7/\xb3(\xbf\xbc{\xb5)\x82\xed\x0b;\x10\xfaI\xa7We"\x06\xcdg3I\xf4\xc9I9\xb4nQ\x14S\x88N\xe3L\x8eI\x8d\x18\xe1\xd2\xf9]%\x0co\xa9'
        b'\xd3\x08\xc9\x92\x03\xec\x01\xf5++\x88\xe7BM\xa4;=\x03-_\x93[\xf31\x8a\xd1|\x8f\xd3\xe7}l\x0c+\x97\x07\x1e\xd7-*I\xc1\x8c}\xeb9\xefB\x93%\xb8\x07_\x08\xc6\x89,\x13\xc6\x97<ku\xa1'
        b'G\x03,\x01)&\x82\xcf\x0b\x8d\xb7\xe7\xbc\x06@\r\xf3O\xc3\x99\xe8\xb8\xfc\x02\x11\xf8Ji3y\x99\x11\xaff.\xab3\xeb\x85\xfa12B\xf8\xae\x9aB\x11\xd8\x82\xced\xf4x\r\x17UP\x00\xa81`~Z'
        b'\xbc\xd0Vh0\xfd-^\xb6E\x97\xab\xbc\xc9\x14PP\n\xf3#_Y\xc1\xaa(\xc0\xc8\np\x01\x91x\xa9)\xc4\x01\x06/Z\xcb<q\xde\xca-\x1a\xc8\xde)T\xb3hQ-;\xba\xb8\xc0\x82|:bp\xca'
        b'\xba\x03\x18\xfb\xafe\xc2\x05\xbd\x02\xfb\x12b\x81\xeb\xe2\xdb\x1at\xd6\xba\x8an\x99\xbf\x02N/\xb0\xee\x16\xce7\xbd|\xe1A\x02\xa1\x97\xa1\t\x8a\x19\xca\tm\x1a\xe4#\x9fV<\xfd\xbd\xa6\xbe{\xd9\xe0\x9d\xf1em'
        b'\xd0\x91x:\xd6\xe2Z\x17\xe9\x0cR\xbc\xb2\x8d$\xe9^*\x06\xbcz\xb6\x92\xe6\xe6\x9a\x0b\xbf\x1cE\x88+\xcb\xa8\xf4A\x14\x0cK\xda\xfb\x846\x98\xda\xfa\xaf\xafk\xd2Y}\xfd^\x10\xaal\x138s\x80\xf8RE'
        b'cBlb\xa6\xe2\xba4\xb5r}\xa3\xb8\xd3\xbcd\x7f|\xc1\x04<\xbb\xba\xfc\xc7P\xc3p\x9e\x06\xbc\xc1F\x05\x99!k\xa0\xc1K4\x8f\xceH~\xb2\x05fG\xfbQ\xbed\x82\x8b\xcf\xa0\xef\x16\x1f,`\xbeV'
        b'V9\xbb\x19\x89\x00\xbfl\xb9P\xe6\x8a\xa0\x99|\xf3\xc8Ij.\x06$\x02#}\x02sj.y{\xd0m\x15\x90o\xb5\xa4\x12\xb2\xb0U[LN\xbd\x0eI\x7f&T[\xa9Y6\xe3*\x86\xb1L\xfc-\x8b\xe2'
        b"\x18Y;\x85lU\xaeDb\x98\xb1\xcb\x99\x9f\x1b\xabJ\n[^\x84\xb1\xafKv\x00_\x84\xdbp\x0c\xe9#\xd6\x97\xda0Jj\xc6\x9bu\xc8\x99\xcf6\xc8o\x04'\xfc\xa2X\xacK\x83zM\xad\x19\xa8\x93I\xf6"
        b"I\x93\xd5\xc6\xb9\xe8\xf8\xa1\x04\xb4\xf1X\x17\xf5\x0b\xb0\x81\xfa%I\xe6h-\xd4\xe2\x8b'qX\x90hy\x88\xc8\x8dHI\rVo\xa3\x07\x8c\xa4\xcb\xf3/\xc8\xeb\x02#\xaf#\x882\x1f\xcd\xbc\x1cS\xacgg\x0b"
        b'5\xef\x9c\xae\x1d\xd1z\x86\xcePI\x10\xe5^\xc8\xb4$%\xe2\xb3}\xc1\xe8\\\xef\xbe\x16\xe7\x01n\\\xc3\x97_\x83$\x8cE\x90\xea\xb5\xc9\xc0\x8d\x99\x1b\xe8\xc9\x12Z\xb0!Lv\xeb\x03\xd3\x876y\xbe^\xa0\xae'
        b'\x94Y\x11i6\x94w\xfdq\xee\x82\xf9\x83\xe0Jxg\xfdj\xba<k0J\xaa\xc8\xf5%\xab\x17\xeb\x01\x95\x0c\xdc\xc4j\x10:\xef<ty\x0f\xa8\xb8:2(\xaf\xd6=AHOR\xf2#-\x992 \xae\xba'
        b'y\xc7f\x939\xbd\xd2P\x12>\xd5\xdc.\xdf\xcc[is\xa0\xd8\xd3+\xa4\xaf\xc2\xc6/\xa3\xab"\x87\xbc&s$\x1b(m\x8c\xbd\x93n\xcf\x94Q\x1d\xc9\x0e\xb6\x12u\xa0/\x93\x83==\xe0{P\x97A\x16\x12'
        b' \xa2O\xbf\xb0\xf0\x1cj}\x9a\xf9j\xcd-\xb5Lycy\xf1\x97\n\xcd\x81\xa2\xe2\xcb\xde\xd33D\xad5\xc3\x0c\x0f4A\x85>\xe9\xbc\xe0y7\xf2F\x9fVg\\\xb2%\xfd\x1fk\xf5\xc8B\xfa\xcb\x98.\x94'
        b"\x06\xa7\xd1\xf8aH)\xacq!\xfaa\x91a_'\x19{\xc6jD\xe7\xea\x80Li\x85\x8c9>\xd0\xbb\xc6\x17\xe2+R\xa0\xae\\\xf3G\xe4\x05\xd3\xcf_(\x9fe\xa0\xed\xc20`U\x00\x98\\\x12\x8e\xd4\xe3V"
        b'\xb1:\x1d\xd2\x7f\xec\x89GDb\\\xa3\xc5\xdb\x0f\x99Y\xe7\x9f\xcf:6\xdd\xdfG\x1dg\xa7h\xc4\xc4\xff\xdc\xb4\xe7\xc4\x9b\xa6\xb1\xc4\xabN\xba\x9b\xe8\x1bavm\xa3\xb3\xd4\x9d8\xff\xe3\xc2\x1c89*\x0e\x92\xa4'
        b'p\xd7\xed\x1b\xe4l\xe5\xe4\xd3\xdb1\x1a\xee\xd9\xca\xe6\x10W\x90\xde,\xd9\x15}\xa5\x1b\xa7\xa2\x14\x8d\xdc\xbc"0B\x08c\xcb\x92d/s\xcefq\xb5\xf3\xc2\xfb;\ri\xc2,x\x17M1\x02W\x04\xaf\xd2\x17'
        b'[\xa6\xabSLF\xa1\xbbO\xaa\xd5\xa6\x04\x04x\x15 \xca\x93{\xde\xc2\xabj\x17V\xfb4\xf4+\x12\xc2[t5m\x8fA\xd3z\xba\x0f\x99\xd9\xd7)\xa3\xb1\xe6\xcf\xc9\x90\x16I\x80\x05ro\xff\xf9L\xc5\x81h'
        b'f\xca\x00\xe1\xeb\xe5\n\x85\x00_)\xc6\x14yD\xb5\n\x8e\x03\x9fUf\xd5F\xd7\x91\xadk\xddnv\x18\xd1\xceSHz\xc0\xe9_1O\xa3M&\x0b\xc7\xba\x01\xa3\xee\xee"Y\xff\xce\x14\x16\x17\xab\xbb+\x86\x07'
        b'\xf9\xcb&s4\xef\xc3\x9f:\x84\xea\xd95\xb6\xfa\xc7"&6\xf9\x95;\xa1WimU\\\xbdS\xa7\x8a\xb4\xdfQR\xe1\xf5\xc2o\x17\x0e(\x9fF\x8a\xb5\t\xb3\xd7\x11\xaa\x83r=\xdb)B!\xe0\x8d\x1a\xd0\xe7'
        b'\xf7\xae[\xb6\xd4\xb7\xa4A\xba&\x9ee\\\xc1\x8f\xd7G\x11\xf86\xdd\x13X%\n>\xbc\x03$U\xc4[[<\x8b\xfbl\xcc\x03H\xf0\xbdn.Q\xba!\xfb6_}G\xfe\x9fc\x0ck\x8b\xad\x87g\xe9\x17\xb1'
        b'\xa3m\xde\x8b\xc0\xd1\xc0k\x18|\xc4\xdb\xe4\xbb\x13\xfa_\xa3>R\xff7 \xf8\xe1=\x08\x15\x9b\x03n\xf3S*\xd37B\x95E&\xf5\xd86J\xfeDsTX?y\x8b\x85(\x035V\x96;\n\xf61\xcdX'
        b'\x08\xbfw\x95\x03~6\xe2K\x04!U\xf0\xd7<\xdd"t\xd2C\x9b)\xd0\xc2\x10\x83B\x15\\\xd1\xa3\xca\xa8\x8c\xd8\x19\x96\x19\xff\xcc.\xac\xfb!;0\x10t\x04\xd9"`\x87\xc6Q\x89\x9a8\xdd\xd0\xe2\xc6M\x9f'
        b'\x96\xe5\x85<\xa56\xb6\xbed#\xf2M\xe7ddS\x86\xea\xdfW\xd7\x03#\xd5\x87\x04\rg\x1d5ij^\x85\xe6\xe8Xm)\x98_\x0e\x80\x90t\x9f\xb2\xbf\xfd\x15\x885\xea\xd3\x07\x96\xc3^W\x9dp\nh\xdd'
        b'\x0f\x9c`\x85R{P8\xd3\xc8a\xcf$wg\x1ds\xd3CI\xb8\x83R\x90\xb3\rmHC\x0cC\x12v\x88(\xd10!j\x8e\xba=>\xfa\xf0\x96\x1f2\xa6\xa6\xa6(]\x84\x901\xb3;%\xa3l\xbf\xd7K'
        b'\xea\xb1\xc9\x98^\xa4\x13\x19\xc5\xea\x0b\x07\x899\xa3\xa1M\x07\x92\xcb%\xe1\xe5t\xe33\xe0\xb5\xbfo\x19\xdep\xce\xcf\xadY\x8d8\xc1\xf5\xaf\xd5\xa2*\xa8\xd9\xd8\xab\x7fo^\xa7\xb33\xc0v\xac\xfc9\x02\x19^!'
        b'\xdfbA\x9f\x1e\xa4\x8d\xf5\xad\x8a\xbe\x1e\xac\xd0\xac\x8e?\xcf\xc0\xa4\xbd\x0f\xe8\xb3\x01U[\xe6\xcf\xc5\xa3\xa8\xf4\x8c2\x01\xd8\r?\xb4OH\x8d\x12\xa7\xfc\xa9\x07\xee\xbd\x1aU\x93N\x99\xa1|\x12y\x94\xd2\x08)!'
        b"\x87\xfa\xa0:D\xd5\xe6vo\xbdz\x0e\xea]\xb2_\x01\xcb\xbe\xd3\x0f?nc^\xa4H\xf7\x02\xffZ)\x9bh\xc0\xf1E\xdc\x19k\xca]\xcaB\x93K'\x96\x8c\xed2\xbe\xc2\x1aO\xe1\xfa\xed7\xfa\xce'\xf1\xaa"
        b'\xe5\xdf\x8e\x8cGr-\xc6\xbb|\xc82*b\x9c\xcfR\x0f\xf6eP\xf1\x18\x8a\x15\xb8?\x11\x9fy\x82\xe5\xaf\xc0\xf8\x88\xb3\xa6\xb7\xe6=\x13\xd3\xa5\xf8\xcf\xda\xce\x1c\xe3rV\xf8\x10)Y\xa1\x9a\xb1\xf1B,\x94\x1a'
        b'\xfc-\x88\xadd%\xc3\xb4N#\xfd\xd6+\xdec\x7f\xec\xd5\xe2\xad\x96Q\x80H\xc8PwP\x85na\xd44\x01 \x14\x80\xbb\xf0%A/\xb8Z/\\\x1c\x022\x17\xdaF\x11;\x10i\x9f\xb9\xbc\x93\xb1\xb3\x80\x82'
        b'\xf4\x89\x16>\xf6R\xcf\xe6D\x82\x1aM\xec*\x91\x0f\x1e\x05\x15\xf7\xf1F5a\xe3\xd5g:\xbdd\x03\xd2\x13\x05\xfbT\x0b>\x893\xbf\xf0\x0e\x8f\x0bQ\xc21f#f\x16c\x1at8\xf1J$\xa6\x0b\xdfT\x11'
        b'\xc6\xc0\xfa\xd4\x98\x08\x1db+7{\xad\r\x18\xaf\xa0\x8b\x0e\x1c\xe4\xdc\xab\x8b\x023\xc3o\xc7\x88\xf1\xb9^\xbd\x18\x1d\'\x0e^\x80\xe8\x9f\xc5\x83\xbd\x14L\xc6\xd9\x8c\xd6\xcen\x00\x8b\xfe\xb0\xfc\xd7\x1e|"\xf6?F'
        b"*\x1a?Z \xbcq(s3G4,\xfc\x12\xe3\x04\xd5{\xe52\xd0\x02\xe2\xe3\xccJ\xcc\\\xc2\xce.\x96\xbb.,\xc2Q\xeb'\xba\xa6a\xbb\xfdN=r\xcc}S\xf9\xb3\x9ed\r\xd3\x18f\xa3\x0f\x95\x0f\xf3"
        b'\x0c\xae\xbfB\x99\x03l\xa2!\xb7\xe9\xaen!\x93=\x93\x0b\x9bC^\x90\x06\x87\\\x8d\x05\xfd\xc2\xe7A\xb7\xc8\x07\tq\xcbZ\xca\xe1\xb9\x0cZFo\xe4\x8e\xdb\x1a\x12g\x1bn\xe3\xa0@p\xe1\x1f\xfb,`Q"'
        b'\xf9\xdf\xf9\t\xe6\xb6\x84\\J\x99\xf4\xfb\x15\x08D1\x7f\xd0P"\xf3\xcafA\x02\x97\xda\xe2\x8f\x00ET\x95\xcfFg\xea\xc6*f \xac\xbcG\xd2\x8c\xe3\xe6\xee\x1a{\xa6\xb3\x87kG3\xd7\xc7\x06\xcc8\x9c\xd8'
        b'\x02\xa7ZSc\x17\xdf\xc2\x12\xebGP\xc1\xb54\xb5\xd6Nwft\x88~\xd8\xd7\xae\xc2h\xb7C5\xceF\x16\x9ez\xc0\x12\xdc\xf2[\x0ca\xa8\x8a\xf4RN\xe2\x8fQL\xf35\x0be\xb2\xc5\xb5\nJ\xa7\xf5\xb7'
        b'\xa8\xc2\x07f6\xf00\x1a\x89\x88L\xcd.S\xe1Y\xeab^\x94\x9e\xe6\x00:\x87\xb4h\xf8\xdd\x91\xacr\x8b\xd9\xef\xf4\x92\xda\xff\x12#IH\xb9\xba\xe9 8"\xd7\x0fw\xadP\x15]\xe9\x7f\xcd\xbf\x98Q\xb7z'
        b'\x1e\xbd\xeb\xe0\xf5-\xb679\xdd\x1d\x8b\x7f\xce\xf8\xa7\x91\xa0\x15V$wm\xca\xc7\x91v\x97J\x9dB\x17gs\xea\xbal\xee\x7f\x8eY\xc4\xebP~\xa6=\xb8Y\x12\xe6i\xb8\xf2\xba(#\xf1\x86\xf3|\xb7\xe1\x10'
        b"\xa6'o\xf9P~\x1f8\xe6k&GiB*\xcc\x96/?\x8d\x07\xb1\x81\x16t\x01\t{S\xbau\x91\x8b\xe9\xb4]FM_P\x86\xc4\x1f\xb8_mE\xe8R3\x86:\xe0\xa6\x9b8#$\x84\xe5\xb3hvQ"
        b'\xf0\x95D\xd7\xd9\xb4\r\x1d>S\xdd\xc6al\xa3\x9f\xd3\x0e\xfbr\xef\xdc\x13\xee\xd3(=\x0f\xeb\x7f\x175.`-\xacR4\x13} ^\x7f\x04\xc9y\xe2J\xb6\xef\x89\xe0\xc3\x9f\x80\xd2*ZRn|\xe2\x11\xf1'
        b'\xdc_XG\xad\xb084\xfa+L4\xb8}\xff\x88\xf4\xcf\xc1\xd0\xc0\xc8xJ\xd1\x8fk\x0c\x1a\xf4\t\x82T\xa2\x8eoG\xc7\x81{\xc2\xa3\xa7\x07\xa6\xd0\xc1\xc3f\xf2\xd2\xea-\xba\xd5\xc5\xb6\xe0\x8d\x80\xf05\x0ei'
        b'\x1f\xdb\x9e\xeb\xf1q\xefV\xf4\xdb\x99\xe4s\xf5\x17Ihuw\x7f\xe6kt\xd5\xfd\x7f\x1c\x06\xc4B\x1c\xc0[\x91V\r\xc89\x8bgD\x87\xa5)2\x87\x9b\x1aA0\xcdg\xc4m\xd1H\xa0Eti\xa8X\xc4\xdf'
        b'\x9e\xd4u\x89\xcd\x0b\xd8\x80R\xf5,R\x0c\x0f0\x9b|\xd3\xd2\x8ej\xb1\xa8E\x97\xfb\xd8\xb2G,&g4G\x1a\x00Lt\x97\xf6c&Z\xa5\xa27Q\x9c\xdc]W\xfb\xe1Mn,~\xa1t\xde#\xa7L\xc7'
        b'Q\xa9\x10gE\xac\xb0\x86;\x91\xbb\xe5\x14UK8m\xa9~_/\xbc\xe8G\xb6\x8eC\x12l\xa8O2ODl\n\x96\x1c\xb7lP\xafVEPUu\x00\xca\xc0\xf5\x13\xb5\x99H\xc2\xad\xb0\x7f\x10\xbdk\x17\xe9'
        b'\xd7\xdb@\xaf!\x85u%\xed\x177\xfa\r^\xdf\xa7\xefS\x95\xf6N3o\x11\xb9\xdd\xbe@\x06\xcd\x90\xc0k\xba\x1c\xe94\xf8\x8bt\x9c\xc8<:\xe8t\x069\xe0\x91<R\xaf\x16\xa1n8\xe4\xc6\x12\x99\x08\x02;'
        b'\xe5\x02\xd0\xbe\x81o\x93\x11\xfd#_(\xcf\xa1\x14\xab\xfe\xc6\xa1\x9b\xdb,K\xb6e0\x8f\xe8\xa9\xaf\xd3\xff^M\x96t\x01}\xa1\x92NN\xac\xe1f\x93\xbe\\\x92\x0c\xef\x01g^\xc1\x87H\xc3\x8ev\x97\xb1\xf5p'
        b'\t\xda\ts\xf1\x1d\x97\x91l\xa1#\xb8\x05\xaa\xd1\xd2\xc1\xf4\xce\xc6\x10\xc2\xc1\xc2\x91\xb6y\x95\xb5\n\xb7\x1e\\"\x8aBb\xa4\xb0\x1c\x8d,\xac\xd4\xebv\xab<\xa9\xa9\x0b\x9c\xfa\xben\x8d\x02\xf0\x8cI\x1b\x0f\xb4l'
        b'\x8b\x9eU3WJB\x7f\xca\x1cU#\xde\xf7%\x12\xac\xdd\xb3\xc7\x83\xe2\xbf\x98bcg\xe1J}\x9e\xfa\xd2\xfe\xc3\xad\x11@\xbc\x19\xb5\xd4\xa1O\xcc_\rt\xd7\x92\x0fa\x12H\xbd\x96w\x19Z\rM\xeb\xcb\xe6'
        b'\x05fmu\xfe\xb5\xee*\xfd\x18\x96w\xbbY\xe9`f\t\xa3\x15I)\x7f\x04J@\n\xa8>\x00\x99_[c\x14^\xb4\xc8Z{ui\x8a=\xf2\x9d\xdf6 \xf4\xe1\xc0@G\x1bb\xd6C\x88s\xcb]W\xb0'
        b'"\xccs\xa7=z\xdea8\xbe\nW\xd4\xf6^\xc2W\xa5\\\xa3\x9d.\xfe\xa2\xc9\xf1\xbd\xa8\xf5\'\xe3\xe7lt\xf1%\t\xecC2\x99w\xfeZ\xfe\x8b\xf3\n\x07\x0b\xab\x92\x97\xf0\t\xc1|k>e;L\xde\xa2'
        b'\xf6\x18\xcf\xc9\xadd\xed\xb6\xf1\x974O\xef\xc8 s\x9a\xf1\xb3\x07\xde\xaa\xf5^\xd6+\xa6\xf0\x9c\xd5n\x90\xe7"<\xc9\xe0\xc2[\xe4U\x88:\xb7\xb0\xdf\xc3Ql\xfb\x9a\x0e\xf1\xef\xa1\x1d\xcde\x8b\xceF\xb1\x1d\xfe'
        b'p\xe9-}!Q\xee}\xe3\x96\rc\x07\x9b\xc1\xc4\xa2q\xf5\xc5\xb4\x93\xa8`\xc1\x12\xadS\xe3\xc6W\xf6\xe5\xa1\x87,\x90\xfeq[\x00\xdc\xd1\xb0\x99\xb6F-FM\xfe\x06Q\xe7<\xea\x14\xacI:\xc4\xd1d\xc6'
        b"5\xd8\x14\xdc\xd6F\x00\xdfd\xeb%\xef\xb4'\xfb3\xa1\x02\xe66}\x9a\x8b\xaao\xb4\xb2\x1b\xd5\xbd,\xc9\xfeq\x1b\xfa\xbe\x93\x94\x8b|*\x16\xdbZgH\xf1\xec\xae\xf7\xc7 \xaaB\x9f\xb8\xba4\xc1lnNg"
        b'\xc8\xa2\x00\xd2\xffW\x86\xa7\xcf\xd3`\x8a\x12\xa7\xb0I\xce\xb0B\xd9\xbe\x8f\xf9\xc2B\xce$D\x8e\xeb\xa1\xd0\xdb\x89*\x13\x8f\x98\xed\x03\x83\xff\xd2\xc5F\xf1\xfc\xbb\xea?_\x0c\xdfV\xea\xa9\xb2Oc\xe0\xb86\x99z'
        b'\x19\xad+\xeaP\xc4E\x98\xa5W\xf2f\x19\n\x1e\xd8\x19\x99"r\xcb\x8d\xad\xf6\xea\x1e\x89W\x15I\x9a\r\x1a\xd8\xde\x1bL\x11\x16{\xf4\xf2;\xc0s\xef\xf6\n\xd3\x85m\x1el\x16\xbd\xac!\xad\x12\xe0\x96\x18\x18\xd9'
        b'\x0c3>/\xe0\xf1X\xc2Tl-\xb6/\x0cP\x92\xd2\x1a_\xb3A~\xa8\xa2\x9f\x06\xa4\x93-D\x1b8\xf2_(\xf25\xbd\xc6\x1d\nR\xb4\xb03o\x00rK\x964\x00\x86]\xaak \x88}\xbbC\xe1\x18\xa9'
        b't\xeaM\xbdJ\xa6v\xfe\xc5\xf2.x<f\x02\xee^\xb0\xcaz\xd0 $\r\x13`D\xcf\x8b\xab3N\x94\xe2\xd1\xf4\x93S\x95Iq\xf2\xf9\x0cG\x17\xa7\xfa\xce\xc8\x0e\xc2\xd1\xeb\x80\xa9\x8c\xe0\xce\xbc\xad\x17Il'
        b'\xbd\xd0\x85^\xd4?\xe1\x91\xfb]\xe5\xb30Z\xf9\xab\x1d\xa4-\xa5\xe2<\xac\x85\xe0\xb1\x9f\xa9*\x03\xc23\x952\x87\x8b\xdc\xf4\x14\x1b4\xf8\x9b\xc5\xb4Lt\x06\x9a\xc6#\x1e\xc2\xf9\xac\xebl}k\x0c\xc0a\xba\xbf'
        b'\xdb\xe7\xf5{\x13\xee\xae\xdd\x03\xa2\x07|\x12\xc0\xf2w\xc5\xcfjmK\xd6\xdb\x80\xd1\xa6\xe1\x18\xd3H\xf24\x0f\xb7\xc3\x10r\x06RG=\x1c\xbe\x02\x18#\xcekv\xf2\xe9\xc8\x80\x86\xd8\xf8\xbc\x8e\x17\x94R\x90.\xe1'
        b"4'?\xb0\xcb\xcc\xbd\xdf\xca\xebT\x12cP\xdb6\xe5\xad\xb4\xf7\x853\x80b\xb4z\xd8a\x8f\xf6\xb14\rV\xc8\x8a!?\x9e\x8b,\n-\x0c\x80\x08,p7\xf3m\x07r\xb3w\x11\xbeu\x9dp\x00\xc4\xa5\xf0"
        b"E'A\x96\x1e\x1af\x80\xec\x92\x12\xceW0\xc4\x06\xb9\xfd\xd8D\x1f\xdbJ\x1b$=3\x9f\xe7\x00\x96\xb7\xdf\x8d\xfb\xdf\xcee\xf7q+\xa9Ya\xb8/\xea\xf6\x97\x9azZ\x04\xb7og\x90\x8d\x17\x84R\xd6{\x0e"
        b"F\xa3\x80\x07\x11'\x12\xc5\x99\x97a\xec&\x13\xc6\x16\\\x19\xf4=8nq\x8b~\xc1\xec\x11\xae\xf5\xc7\r\x14g1\x7f<4\x96]\xbd^\x08\xb1\x15S\xce\x0b\x1eX\xe8\x88\xdaT\x04L\x95\xe4\xed\xb1\xb6\xa4W\xf7"
        b'\x01\xb3\xd0\x13o\x8dD\x8a\x04,\xf3\xf7wx?E2\x8fw\xfc\xe8Q\x1c\xfc\x85\x80H6f~\xbddR\xfdk\x9a\xbf\xff\xc0EB[\xec\\\xd2\x1b\xfe\xf3\xcc\xc8\x0c00\xd6K\x87{\x1b\xe8l\xed\nR\xe3'
        b'\x1e,u\x9f7s\x86\xd8\x102$\xde\x00A\x7f#\x15\xd2\xbdt\x94\xaf\xfe\x07Z.\xb7\xff\xa6\x81:FH\xff\x17\xb4\xed\x91b5\x9d\xe8\x9d\x8dz\x86#\xa0q\x82\xd10\x12z\xa2"l6\xd1!\xaa\xb3\xf8B'
        b"\xe6b\xe7\xa2z\xd0\xd5\xd7\x96;\xff\x9av\x9d\x1c\xfb\x85\x93n\xcd\xb0\xef9'v:\xf8O\x8b9\xabE\x0b\xe1\xcbk\xc0\xe3*z\x98\xee\x15\x03.-do\r.\x8dl\xe8\xb3\xb5I>}\x174\xb8^\x98\xf6"
        b'\xb4\xeeq^\xdeK\x0e\xa8B\xc6\xc47My\xb9\x05\x95\xead\\\xeco\x03#Zh,\xa40\x12RM\x1aC\x9c\xc5"\x1d=\xbcM\x03\xf78\x0b\xc9t\xaa\x18\t\x0f\xf2\xa2\x14\xba^\xb4\xe64\x97\xc0\xc0cy'
        b"F@J\xd8u\x93\xa2j0/g\xb0Z\x1ey\xfc-\xd3(\x194\xa3f]\x9f\x99\xc8'b\xa6\xd1z%\x88\x1e\xbc\x87\x99v\xb3\x15\xf5\x9fg\xf0\xc2\xa6\xed\x83\xf28\xe9}\n\x115\x0e\xb4\xbf\xed\xba\xd55#"
        b'\xb7\xbd\x1a\x90\xaeo]\xbc\x17\xb5\x08\r!\xd6*\x8c\xf4\n\x17\xf7\x81(\x0c\x8b\xd8\xb9pU\xc5\x13m\xc0\xcf\x99\xdfM\xd2b\x19H\x07\x80\x87\xfbF&\xb9P\xde\xda*,\xb2\x8e\xeb\x83\xaf\x04e\xaa!2\x95n'
        b'\xa9\xcc\xe7p\x8e\x11\xf9_O\x17\x12\x97\xb8\x8dd\xd8\xd1\x007\xf6\x88\xe9\xc5\xdc\xf8\xfb\xc1Sc\xf9,\xd2v\n\x1b\xf5\xef\x12\x92\xab\xb5\xf9\xc3L`x\xf7UJ\xe6\x93\x83\xbbG\xf3\xfa\xcb+\xfb\x15Xsw\x9e'
        b'\xa6\xcc\xb3^\xe7\x9c\x84L0k\x08\x19Xv\xc2\x9ec\xbfyn\xe8\xc6\x1a\x8f\xdddH\x0f\x06\x81\xc0vN\xfc\xf2\x86\x00\x15\xd4|3\x86\xdaR\x06\x9d\x0f\xec\x16\xeb\xbb\x15_I\x85e\xf1\xa8\x19\x82\xe3\xf3D\xb9'
        b'r\x13!\x94T\x13\x9a\xca6\xd4\xfe\xa2\xd3\xa4\xea\x1a!%\xaeN\xef\xfc>\xf8\xf6\x86&+\x07c\xd7\xca\x1e\x99M\xa0\xddq"P\xd4\xf6h\xc8\x93\xf2\xcaM\x10\x0c\xa4? \x93\x08\xb0\xe5\xbe\xe1\xadS\xad\x8b\\'
        b'=\x97\n\x17f\x08-\xb3\xcd\x82~\xf3e\xc8\xa1~gF\xd4{E{\xb2\x80\x06,K\xd8\xcf\x92\xf1\n\xd7\xce\x94\xa6,\xdc\x9f\x93\xc8+\x9d\xc5\xfc\xf7<\x92\x87\xd2\x0e\xce\xab@8\xc6\x0c\xe2\xc1z\x7f\xc6\xf4\xbe'
        b'>\xf2\xc4\xf6\x8e\xd1\x12\x92\x95`O\x0c\xee\xfdBK\x0bCO\x17p\xec\xcd{\xb6\x1e\xbe\xb6\xc7\\\tY\xe1\x9d\xbd\x85\x9a\xa6l\xce\xd1C0\x16@\xd0\x87\xa7\x02\x88j\x96\xbc\x83\x8b\xae\xc4\xa6F\x0e\xa4\xc5Jq'
        b'\xc9|\xf1(#k!\xe7R\xf7\x89\x80\xed\x95v\x8c\x1ac\x00\xa0\xf3\xc1\x03\x1f\xab\x85\x06\x9dq\x17\xb4s\x0c\x18\xc1\xd8\x93\xbdP\xc4\x15\xe5\x88\x83\xf0\xc1bADDn\xeao\xe3_hRF\xdeTySt\xd7'
        b'q\xc2~\x99\x8a\xb9\xfb>8Qa\x85\xacZ\xad\xfd\xdfF1^\xa3\xac\xb9\xa5b\x98\xdf\xda\xd8\xf5Q\x04-4\xb1\xca\x1c\xe2b\xad\xf6\xe41|6@\xad\xef\xdf\x8b\x7f\xb7\xd7-`CT\x8c\t\xf8\xea1k\xa9'
        b'\n\x00\x0f\x0e\x1d\xd2\xfcg\x8a\xd5\x13\xf4\xc3\x85=e\x9a\xfb\xee\x1a\xb8\x9c\x0b;\xfe&]\xab(\xeaC\xaa\xdeE\xd56a\xc1\xc3\xb1@\xae\x14\x1c\xd7:7P\xb2\xc1\xe3nm\x96Yx\x01\xbd1,\xa1\x87\x13\x9f'
        b'i`=\x04I\xd9G!\xc3\x1bp\x8b\x89\\l.\x19\xb1\t\xf1o\x1a\xc3j\xbd\xbd;\x9e\xe5y\xacn\x8bJ\x89u0d\x0c\xff\x8f\xa6_/\x95$\xfe\xb3\xc3\xb7\xbf~DZ\xcc\xdc`\xc7_\xf9\xcf\xf7\xc1('
        b'\xac;\x9bOc\\Rl\xdf\x8cc%\xfe%\xffz\xec\xedn>f^\xbbw@\xef\xf4\xb9\xabu\x1fD\x9c7\t\x1c\xf69T\x13\xc4\x13\x95\\=\xca\x02p\x9c\xa0&ch@\xb65\x7f\x86\xdb\x8c\xde=\xd33'
        b'g\xfe\x99\xf8:\x0b\xd8/\xac\xcd\x12\xd5 }dmRA\xf6\xe4v^ELK\nK_\\q\xc5\x08{\x0c\xb5\x16E8Z\xdc\x9e\xfeX\xee6@\xed\xba\x93;\xad[jl0\xedi\xca\x0c#LE\xc4\xa4'
        b'\xe6\\\xfa\xd0L3Z\xd4\xdf\xd8\xe0\xa15\x08\x8aq\x14\x02\x8f%\xed\x7f\xc6\x94\xfa\x89%\x99\xb2N\xfc\xaa\x85\xd6\xe8\xe8\x84;\xa9M-\x8b\x10\xeb*\xf2}\xb1\xe8E\xd0\xdd.ga\xb9\x97\x1fc\xc4\xb6b\xc9\xc7'
        b']1\x80\x8e\x97\xbcz\xf8e\xf1gg2\xa9y\x93\xac\x039\xc7\x19\xf8\xd9\xce\xf2\x04\xcba\xa2\x1f\xa8\x03\xff2\xff\xdaz\xc1M\xdb2\xf1\xb2b\xe5}>\xb6\xb4G\x19\xeb\xe4\x06\x08\xaa\xee&}\x99\xdb\x0e\x1b\xa6'
        b'\xf6\xcc\xc0\xf3\x8fZ\x18-\x10\x89r\x0f\xa5\xe2\xc6}\x91O!e\xe0+\xc2\xceg\xcb\xa4\x0b\xa7\x01=\xf6v\x18K\xe4R/\xb4\xee\x9aZuR\xa5\x89e\x1f\xb7\xa9\r\xfag\x93\xed\x10\xa8\xf0~\xa2\xbeN\xcfn'
        b'\x9b\t\xd9\xe0\xaa\xae|=\xd1\xa4\x11\xed\xe0\x89\xbf\xedd\xfb\x9c\xfb"\xd9\x83Rg\xe3\x89I^\x98\xdb\x93\xf0v]Q\x98B\xa9\x83V}\x8c.?t\x9d\x17m\x06\xcd\x9cM\xa2\xab7\xd7\x8f\xa0\x03\xe9\xe0\xfbI'
        b'\xfbV=Dq\x893a\xc1\xd4\x0f\xbd\x87\xe6C\xcd+Si\x94m}Ti\xc8\xf7T\x9e\xe8pQq\xa5\x18\xc0\x13\xee\xd3_\xa9\xd1%\xff\xd5\x1e\xcd[d\xbf^+\x0b\x82\xbdz\xb9\xbe\x88\xa1\x98\x85f\xae\x7f'
        b'i\xe0|\xf9\x0c\xf0wK\xfb\x99xP\xef\xf1:U\x1c\x12\x9f\xc2\xcd\x19\t\xefE\xc5\xe2x\x06\xc8\xd5\x9c\xbdn=\xb0\xe6tC\xd7^\x98Lj|aq\x9e\xd9P\x1dr\xa4\xa9\xe1\xcb\xc5K=\x1aI\xa8\xd9\xc6'
        b"\x89\x14s\xcf\x84=ej\x17/Qu\x84\xb4\xff\xa3\xd7v\xd2\xb6\x9er\x91V\xfa\xcc\xc1\xa7R\xd3\x11@\xdd}\xf3<G\xb0\x16\xf7O\x1f.\xef\x96\xec\x18e\x9f\x0cZ\x17\x8f\xdc\xbe^Bf'1{\xfc\x81+"
        b'\xfc\xaf\xc2\x9ef\xfd;\x1cr1:\xdb\xa8\xbdd\x19\x17\xaf;\xd9\x106\x15\xb6\x8c\xfc:\xff\xb40U\x93\x18R\xba\x9b\xd0nx\xcb\x97mo\x9ecH\xe4\x9b\xa8}\xf9w\xa2%\xc1\x8fX\x15\xf6\x9a\x97U\xedp'
        b'\\=\x0f\x8c\x88\xc5\x12u\x17(:\xdb\x17\x02\xea\x93S\xea\xd1\xe4b\x8c\x7f\xe0\xbb\xf8.\x00p$);\x01u\xe6\xb6n4\xaf\x1a\xc4\x03\x1a\x807r\xc1Ch\xf1\x93\xc9\xcf\x0b,\xb1\xf8\xc7\xd9\xa2\xd8\xf3\x00Y'
        b'3\xe0\x94\xed\x13\xb9\xd8\x16\xa6\x17\xfd\x059+}j\xfe\xc3j\x95\x0b\x10\xc6:G \x86BQ\xe9C\x93\xd5\xe6\x8c"\x87_\xaa\x8c\x9f\xaf\x88:\xe0qx{F~\xeb\xbe\n!!4\xbb\x1eTR\xfd\xce\x00\x06'
        b"\x1d\xa7\x9c3Esg\xa9\x81\x92\xc8\xa9!\x15\xfd\x15\xb7\xa3\xa3%\x9f\xcd\x0b\x9b\xf8\xfc\xd6\xc3\x85\x15zN\xd3`\x93/\x1aI[6\x19)\x89\xc2\x8f\xde^'P.\xb4X\x8e\xfd\x16M\x99]b\x87\x9c\x07\xb6\x19"
        b'\xf78p\x9c\x99\x97?\xd1\xdf\xfa\xb2\xed\xc8\xee\x83\xb1u\xb9\x04|\xf7\xfb"\x8de\xf7@\x866\xfe`\xb7\x15\xe4HC\x95\xc4\xdc$x\xacA\x9c\xcd\xc3\xb7\x90\xf1z\x1b\x8bh\x8aj\x84\x1aL\xb1\xb9\xcb`\xc6B'
        b'\xfd\xa5N\x08\xb1\xb6\xd6\xf7:\x127z\xe9\x88u8\xd2\xfaCg\xc8?\x17\x8b.\xce\x93\xb0\x82l\xd9\x181\x8e\xf1\xea\xe5\x9d\x8b\xce\xb0\xab\xc7C\n\xff\xff\x03Y\x11G\xcb\x91\x90\xa3\x90\xee\xa0\xd4(|\xe7\x17f'
        b'`9\xd4\xa4\x05\xc4;\xd4\xaa\xd5\x8bt"\x8e2\xe4;\xdcM\x11\xafqu\xe9QwTF&\xd4W(nX/\xaa\x86\xa5\xb8\xee\x93\xcb\x81`Y\xd0\x13u\xfe5,\xec\x19\x1f\x98\x96q\xb1R\xc7\xae\xfb\xb6n'
        b'\xd6\xd6\x80*\x1e#\xfdX\x19[rR\xd4\x1f\xe1\x0c\xd7\xe8\xff\x8eE;\x04\xe0A2\xee\x17\x99\x90G\x1a\xb5\t\xd8\xd0\xfa:\xfc)\xcfh\x9aC\x9as\xc2\xc8c\xc9\x03\xf3\xc1\xe1\xa5\xa1c\x9a\xd4\x02\xe8\x1b\xb3\x88'
        b'\x88\x16\xbd\x94!\xc4\xc3\x97l\xecc>\x84\x94Q,\xb6p\xcd\xc7$d\x15\x08L{\xa3\xfa\x82\xeeii\x1e~\xb7\x00\x9e>\xf6~N\x9e\xb8\xf9\xfb\xf5\xd7\x18t\xc2UW]Q|\xa5\xa7$\xe7\xc9P\xa3\x10O'
        b'\xa2<\x16mi\xc1m\xbd!fU\x0f?^5%\xd3\xac\x11\xf8\x14\xc5\x93 \th40\xab\xb54\x0e\xa7\x04\x88R\xebD\x86\xd2=d\x830\xd2\xb8\x94\xf05\x89`\xbe\xde \x91\xc3\x13a\x81g{\x0c\xc9\xaf'
        b"qn]I\xbf\xe4\x8ee\xbf\x07M\x8a\xf3\x10\x83\xe4\x81\xc0\xf2\xe83g3\x04\xb9\xb1\x898(*\x87\xc5\x01y7?\xeb\xf4\xae\xfa\x90\x0f\xd1\xfc\xc35\xd3\xc7\xdd>>\x8f'\xa5\xe1\xfe>\xd0NZP\xf8\xe7\x8b"
        b'{\x12\xf0L\xab-\xd8-Y\xf6\x084\xc9\xf6\xa7J*sY\xdc\nH\xedE\xaf\xe3]\x05D6\xb47Z\x18\xd8\n\xd20\x953\xd0\x88\xf2\xd7\xb0\x0c\xb0\xba\x0c\xe7\x8bF\x1dM\rr"\xc0~\x89Xt\xcaW'
        b'\x0b7\x1a\x18\xc4\xecT\xad\x818s\x9f\xfc\xa1\x19#\xad\x82\xe2CP\xd0\xd5\x9b\xad\xde\x86G\xa0\xb5<\xcd\xae\x0c\xaf\xd3\xa4#\xac\xc0\x9cFf\xabd\x0e\xb3\x84\x8e\x85\xc2\xa5""\xdd\'O\x1b\x03/!\x9b\x8bt'
        b'{\xdc\ts\x87\xa4\xf4L#v\xd6\xa1P\xb31\x0e\xa4\x10\xe0\xd2#\x1c\xf6d\x81\xd5\x86;;:\xad\x0f\xfbt\xb9\x11\xf9QLg\xc5\xc4{\xe9\rn:\xa3-{\xfcW\xbd$\x1a9\xc7\xaf\x00-\xefg\x96\\'
        b'\x16B\xeb\x91sl \xe2\x02\xf4\xf5\xd8\xd8\xa1w\x0e\xe2\xa2\x14\xc4\xd3\xf1\x01l:x\x9e\x82(\xa3\xb6\xccv\xb3\xd8V\x0e\xc7<\x90\xee\xb01\x88\x90\xce\x9c%j\xcd\xb81?a2\x06 \xb5\x8e\xd5\\\x9f\x93\x08'
        b'\x8c\x11W\xb9\n?\x82\xbf&\x91\x03&?N\xe2\xea\x0c\x14\xf9\xb4\xcal\xbb\x98Fn_#p\xf9\xdf\xd9\xb4\xd0\x9b!SJ\xe0\xe8f\xf8X\xac\x8a\xf7\xb6\xbd\x1cUU@\x01\xec\xa1\xa0\x9b\xcfT\xf0\x89a\xa5\x8c'
        b'\x02w\x10\x14\xe2\xc6\xe3\xfe\xba\x1b\xb8x?6\xd0\xae\x94\xa7\x00\xa8\x90\x02\x83\xb9\r\xf0\x8d.\xe5\x15\x7f\xacv\xe7\x8d\xf70\xb3DP\x17TC\x19S==\xdd\xd7\xa1\x85\xe1\xbc\x90\x95>\\\x00\xc3\x01*\xf6\xdc4'
        b'\xe0#\xac\x0c\xdb\xa2\x0bs\x16\xb7\xe2E\xdf\x17\xc2\xac\xaf\x06\xd6\xdb\x1b"Afpy\xd5AH\xc8\x89\xe3\xe9^R\xd0\xed\xe9\xc0\xa1#\xc4B\xdd\xf7\xd3\x19\x96\xddM<\x03\x0e{\x1f\x97\x9a\xd9\x13\x17\xee\xb4\xf4}'
        b'\xae\xf2\xf1a\xb1\x7f\x86\xa6p\x179\xb0\xbc\tG\xd8\xdd\xc2W\x0f\x83*\x81\xa7y:\x85\xb0<@z\xe8\xdb\xd7\xc6\xb0\x0e\xa8_\xa3\x9e\xf9v>\xb1\xd3\xecL\xf0}\xd2F\x80\xf7[\xf8\xec\x9d#m\xd1\xa1\xf7\xe3'
        b"n\xc9\xcc\xabS\x8f\xa0\xf1g;[\xe0b\x9d\xf0\xdf\xa0\xb1S\x12\n\xb9m`g\xb6\x93\\,\xc5tO\xf5\x12+\xb5\xa2\x1f\x18\xa6\xfc\xec'\x83Y\xef[2%[\xa7\xb9`I\xb2\x17\xb9F\r)\xfbK\xf8%"
        b'\xfc\xa5&\x9a\x94\xf8\xf2v\xe2)`\x1f\xda\x0c\xc2\x9chZ,\x05+@{v\xd9\xaaaBB;\x18\xc8\xe1\xdd\xf1\xcb\n`\xbeW\xa1\x98\x86_\x82Q\x05\xda\x17J\x17\x8c\x16\x1f|\xa7\rM\xc4\xb0\xb2\x8fT\x0b'
        b'\xb0\xad\xe9\xbf-I\xf3B\xfe\x00fU\xd8\x12p\xed\xb9\xfc2\xe6\x8b\x8eL\r>\xc7\xc2M\x96\x84O79\x1b\xab\xbeN^v\xa2cG\x87u&)\x83\x7f\x05\xc9\x91A>\xac\x1f\xb0p\xad\x85\x8cv/\xa4\x10'
        b' \xc5 \xed\xc8\x0b\xfa\x1e\xc0\t\r8\x80(I\x8ey\xdd,\xb1\xc5\x91\xd3\xa4\xca4\x80\x91.r\xed\xee\xfbT\xe2\xab\x13\xd6\xdaT\xcf\x00S3IY\x90\x84\xd2J\xcc\xc4\xfc\x1f\xf1\x86\x02\xc9\xd6\xd5\xe1\xe2\xf4\xda'
        b'\t\xecy\x14\xdd]6l\xc0\xcb\xdb\x00n^\tkofJ\xa0&\xbe"\xb5|\x82\x82\xba5\x1a#\xb7_\x11\x98\xf0\xc2#z\x1f\x90b*Fs\xc0\x18\xab\xf5\x1f\xa9N\x123g\\37\xf2H\r\xd2\x82\xb0'
        b'\xf1}\xe0\xc9\x9aOe\xfd\x9d\xcb\xe2\x816qq\x163\x02\xa8\xb2!\x18\'i1\x08\x9f\xf9\xd4\xebD\x8c\x97j\xa2\xcb\x0e<<lgu\x7f\xcb9@\x08;UnDe\x98\xf3\x15\x9eN"\xd9\xcb\x12\xd4\xca\x92'
        b' \x8a\xe9L\xf73\x9f\x04MR<p\r\xc0Rda\x02:\x7f\x18\xca\xbe\x8e\x11\x9a\x987\x84FG\xe5\x18O\x97\xf1\x7f\x85\xb0\x05|8,\x97fR\x84T\xdc\xc8pl\xbc\xac\x87\xdfLR\xfd|\xfe\xb7\r\xa6'
        b'\xe1\xf7`\xd6\xcc\xc9\xc8"4\xc9~\x94\x04\xa5\xf2\x12\x9a\xb4\n{\xf2p\x04\x99\x8b\xd7\x17\xc6r\x82\xe6\xc9p\xdc\\\x9fS\xfc\x88\xc2m\x84\xf9\x84\x15\xe6\x19i^\xd2\x90\x8c\xb3\x8a\x08;\x0b\xdceL\xb7<gM'
        b'\x02\x80\xcboKT\x8eh~\xcb]7\xc9\xd0\xcfH\x1c\xdb\x96~\x91*\xcaW\xd41T\xd5xk\x96\xa0\x81X\x95*\xb0\x0e\x89X\xfeH\xc8\x02\xd8r\x1e\x1cc\xa3\xf4\nvd\xc4G%\xe2Y\xf2mW\xe8\xe6'
        b'\x8a"\xe7j3\x19\xd1$\x03\xf37\xe7\xca\x8cj\xaa-\xb5\x9c\xda\x8b7\xc9\x15Q\xc8\x14\xb6;]\xe8[\x8b\x8e\xe4\xa6W;]\x06\xeeH\xf0\\\xfc\x10>\x9a\xea\xf3\xe9\x0bN_\x81n\xb9\x8e\xc9\xbb\xf8m\xdc\xc0'
        b'\x88\xd1\xb6\x12\xfe\xe5/\xfa\x8fB\xfa\xf8\x87\x1cK\x12X\xf0\xa8\xb5yL\x9b\x86\x91#!o\xd7\xfa\xb7\xf4\x90B\xc4\xf2=\xd1K}W\xcb\xea\x92\xd2\xe5\xbb?\xda\x88\x0f5$[\xa5\xc82\xed\x179\xa4\x01\xc7|'
        b"\x95\x82\x91\x8eeL\xdb\r\xb8yx\x18\xaeh\x95\x80p[\xcfO\xd0l\x0e0\t\x97\xb8'b\xaa\xe9\xc9\xc2\xf1\x1e\x06\xa3\x85\x8f*\xf4\x17Mht\xe5\xb2\x0ce\xc9\xc50\xbcW\xe9\x06\xed\xf4\xcbP\xb7\xcc\xd1\xaf"
        b'\x97\xd1\x12\xc1\x1e\xed\xa2\x12\x87V<\xab\xe0\x1e\xf5[0\xb4\xe4\xac\xe3\xd5z\xae\x11\xaew~\xb3ee\xbb\xc7\xec1_\x88\x1e\xb2gWj\x9c\x94\xda\xd7q\x02\x1c\x87\x94\xa2\r\xb1\xf7\xccV:E\xd1\xe7\xe1\xbag'
        b'\xe9\xc5\xb3\x17\x11\x92\x82\xd1t\x94\xb7\xbb\x99$\x8f\x8a\n\xea\xe8&R#5\r\xcd\xfe4\xa6\x11`\xb4\xe8%\x800\xb2\xb3\xb6V\x1e\xc9\xf13\xfa%P\xec\xc6\xccD\xe5\x84\xeeY\x97\x15\x17\xb2,Ge\xbc9\x88'
        b'sP8zU\xf1\xff\x00\xa0\t\x87=\x8a<vm\xe1\xe8\xf1$\x03n\x96\x1f\xc6qR\xb9\x08\xdd1\xc2O\x19\xacPe9\xe1QK+\x9a\xebL:\xe7\x81Io"\xb5\x8fFR\xfc\xc9\xc3@D\xc2s\x80\x18'
        b'\x84\x0cB\xb6\x00\xbc5a\xbb1\x84U)5\xad\xdd\xc8>k\\\x98\xf1M\xec\xfd\xba\xceq\xad ?9o\x8bo\xe3\xad\xff\xce\xd5\xb2\xe1\xc4\xfe\xc7c\x1c\xc9\x89KqV?ro\xe3\xb6Bh\xcdyl\xaa\x15'
        b'\xe4?\xe1\x82\xa3g\x9e\x91p\xbc\x1b\x7fDp\xe2\xa0\x08\xf7Z\xc6\xe3\xf6Zt\xbf\xee\x9d/\x91+\\I\x99\xfey\x8d\xc4\xa7#\x1d\xe2\xd1\xfc\xe5`\xde\xa7^~*>j\xec\xea\t\x17\xb8\xd4u"V2f\x89'
        b'\x8bK]\x99\xf7\xdc\xba\x02B\xeb2K\xd7\x86\xcf@\xd4!\x80r\xb9T\xe7}_\x91\xee\\\x82\xcc#\xbd\x8e\xfa^n\x14\x04\x97h\xe3\x10Q\xaf\xa8\xf2\xd1i\x9a\xca\x0e\xe1\xf1\xed\xec\xd1!\x98gl\xa8\xf5\xe0q'
        b"}\x1c\xa9P\xc8\xb8\xd8\xf0\xa4\xea\xd6\xca\xef\x84\x8c\xfe\x97\x80\x8c\xf8\xcf|\xe6\xda\xbe\xd3VG\x93\x93'\x1c\x14\x1d\x80\xefv\x1e\x9b\xce\xde\xef\xd1\x93h\x8ap\xef\x81\x15CC\x95,\x11*\xaa\x17\xdd5\x99\xf8R;"
        b'.\xdffK\xde\xfb\xb9\xb7W\x02MF\xf5_\xfd<g\'\x14\x84\xb4^\xb3X\xa6"[\xa5\x81\xf5\xd8\xfa\xfd \x00+\xc8\xa5\xect\x16d\xe4kt\x17hF\xd2\x0e\xe9\x06\x99\x13-3A%\xba\xd6m?/\xb2'
        b"\xf4\x0b\xcc\xcdy8\x11\xbf\xd7\xa0T\xdd\x12(\x84\xe9O\xc8\xfa_\x0c{\x86o\x14\x8f\xb5\xc4\xbc\x0fk\x81n\xf8~Ez\xa6\xba\x82\x83\x8d\xdfP\xc9\x15Qv1'\x9a\x13\x83\xc7\xfde\xc8\xdaR \x842\xf1\x08"
        b'v\xc8J\xf6\x17\x17\x83\x97=wm\xd3\x1a/\x901i\xbdi\x82H\x90@\x0f\xa1\xfd\xd1\x19R\xff\x85;\rG\x1e\x0b4a\xa2\xff\x10\x0cE \x84\xb9H\x99\x079\xbfj\xd6\xde\x9fV\x96@\xfb\x03\xc9Yk\xdb'
        b'\xae\xd1W"\x12s\xc9\x19\xbd\x81\xb2ul\x06m\xc6:L4\xdb\xfc\x0b\x18\xdf\xd71$\x92\x05\xa0:R=\x196\x00\x8e\x01\x808\xc0\xb6\xce\xff\x88\x81\xf2=\xc4gO31\xd9J\xc4\xad\xce\xbbH\x97\x11c\xcf'
        b'n\x06\xcc[\x85\xf7S}u2.$-].\x1f"\xe4bYb\x92\xa5k|\xeb\xa9W\x85\xe3\xaeV\xeb\xebH\xb9\xb8<RLj\xfe2\xb8G\xc6>\xab>\xc0\xba\x01\x14\xda\x02\xb5\xc1Nd%\xdb\\\xaf\xa4'
        b'8I\x84*\xd3\xdd\xab\x84\x86.\xaf\xcfR\x92\x86aV\xcb\xc4\xd4\xac6\x82y\xbc\xcfy\xc2\xdf\xe3I\x83\xbe\xf1\xff\xd7\x96\x15\x8b\x99?\x87Aq\x8f\xba\xbd\xc4\xa2c\x82?D\xd1\xb24Nq\xc3l\xa2\xbd\x0b\xf7'
        b'\x10\x9d\x91b\xb1\xe7\xaf\x88\x05\x1dj4\xcc\xb6>\x89\x87\x8b\xa85\x87*\xecq\xbd\xd2\xb0\xf3%\x10\xe7\x83\xd9L\xa0\xcb\x98\xfa\xee\xcf\xc2S\xd2\x911\xeb\x90}0P\xc4\x07Xp|\xaf\xd8\xfa1&\xfd\xe1u\xd9'
        b'\xdahdur\xb7\xe5^^+\xc1\xaaq\tCi\xa7f3\xd9\x89,\\\xd7\xa2\xc9D\xa8w\\2{P\xe7?d\t\xc7\x16\xa2\x06\x93\xcb\xd1\x1f\xf2\xbfJ\xfeUZ*{\xaaN\xb5\x7f\xc6\xd2\xaaAeS\xd7'
        b'z\xbb\x98\xbb\xda\x87\x8b\xed\xa5Y[g\xb47O\x15b"]~\x15y;\x99\x80\xc4\x81\xba\x1a/h\xd1\xd5\xc8`vU\xa7\x0c\xd5\xba\x15\xb7\\\xd0\x89;\xf2%\x89\x130\x00\x8e\xb2\xb3\x15\xd1\x11\xf7d\xed\x1b\xe4'
        b'\x18c\xe5F\x87G\xcd\x9c\x9fR\xd8_\x99\xffd\xbf0q\x9f2aX\x88\n\x07\xa1\xa2q\xe2\x92\x18\xdck\x95#\x03\x071\x19\x05\x83f\x11a\r\x9aP\xe4\x94\xcc\xdda\x8f\xb2\x9f7T\xbb\x1e\xf1\x92\xb1-]'
        b'\xb6T\xae\xe9>7Bh.\xdaEEo:&/v\xf4\xc6\x14\x8b\x9b\xe0\xba\xf2\x82\xa71h\xe2\xdf\xd47\xc0a\x1aG\xc7\xc5_P\tkv\x95\xce\xf8w\xe5e\x10b\x85\x9b\xd3\x15\x82\xe5]g\xfbW\x11\xf4'
        b'\x9dF\x1d\n\xfb\xd5\xd1\xfbgIjv+\xfd\xf4\x10\xa0B\x8d\x96\xb5\x90\xeb\xad\xc4/p}q\xcbERWx\xcd\x88\xc0+)q\xda\xfb\x15\xc5mR\x10\xb1o8\x11*t\xe1\xe5\xdc\xad\x8d\xb4L\xd1\x96B\xff'
        b'\xaaN\xfb\xa5M\xe1\x8a\x07\x92\x1f*&t\xd0\x8a\xdc\xe2j_\xa2\xf1g\x18\xc6\xcd*z\x14BM\x11\xfe\x82\xf8\x9cDo\xa9\x1c\xdfK\xf3\xfcL/\xc4\xe7\xd6\xda\xd5u\x8b\x01\xbf!u\x13f\x0fm\xb7\x9a\x97\x93'
        b'\xc8\x02\xdb\x05\x0eL<\xda\x03\xc2\x8c4\xfe\x8c\x86\xb4\xb0*|\x06:\xac\x88\x0f\x13\xc1\xc3\xde+\x9e\\\xa1\xc0\x84\xf0\xfb\xd9\xde`MbS\xe1 q;\xf6\xb4<Aa\xe6db\x94\xb5\x06\xdbc\xc4\xb7\xc7\xd5\xab'
        b'Ha~\x1c%\x8d\x9f\x9c\xc1/\x82\x0c\xdb\xed#8C\x04\x99\x12\xae\xad\xda\x8f=\x04\x11}\xc4m\xb1\x81\x1aJ\xa7\xd4\x12\xe2\x83q\xceE{\xc4\xccy5-\x03q^\xeb\x13\xfe\x7f\xd6\x01\xf7sF\x8c\x80\xcfJ'
        b'\x9e\xa9\x06\xb5\x9a(\x1b\xe3\xf8\x88T\xa4\x118\xa8\xd9\xe0\x85\xc9"C\xf9\xeb\x0f\xfaNM\xab\x81[t\xb8}T\x1f`]\xc7P\x7fv\n\x9fm\xa1\xa6\x8c\x0f\\\xa6+\xbdOT\x18\x0b\x0fLw\x10\xdc\xb1\xccx'
        b"l%\x16\xc9\x94!\x1aw7E6_\xf8\xd6\x07L\xa1\x9a\xa1\xba\x13\x97\xd0'\xfd\x9b7\x97\x15y\xd4\x19\x92\xddr\xdafd[\x13\x9df\x1d\x91\xcb\xef\xb7)\xb3c\xbd\x15\x1f\x84n\xaa\x8c9\x0cr\xf6h\xa9\xe3"
        b'\xca1\xb6+\xa4.6\xd1\xeb\xa3\xb9`.yE\xec\xaa\xc7\x9cr\xd3\xdfp\xf3\x8b\xf2\t\x03\x06\xf12Wh\xbc\xf1+6J]\xc1\xf9W.|\xba\x0c6\x0b\x19\xf8\x97\x06\xbb\x8d\xb7\xfdg\xd2\x0f\x90\x88D:v'
        b'DC\x00\xbb@n\x1f\x1e\x90\xaf\r\x9e\xf4nD\x12^\xf0\r\x9fj\xe8T\xa9\x86N\xa4hj\xc7J4X\x94{c\xbfb\xdbu\xd1\xa8$\xa0\x9b_\xf0\xdc\xbe+\xc5\x06\x0c\xef\x8d\xd0\xd5=\x809Y\x9e\xfa\xf8'
        b'\x0b\x92\x01\x89\xec\x04j\x85\xae\xe6f8{\x1fB\xb5m\xd0\xc7g\x82\xa5_\xfaR,\xbe\xe0("\x02\x089\xd0\x17}\xf4l\x06U\xab\'/\x11\xdb5\xd5\xb6\x11\xf0\xf8\xc1\xe7E\x1ah\xba\xca\xbe;\xff\xa0\x7f\xff'
        b"\xfc\xef\x1a\xea\x8b\x14\x94\x9e\x9d\x97\x9as\xc7p'\xb1bY\x9cE\x9c\xf7:\x90Q\x00\n\x84\xd7\xdd\xa6l\x82yzRQT>Y\xc3\x126\x93\x02\xfb\xe1Q\xeap%q\xfa\xb3!I\xe9\x82\xd01\x06\xfe\x8c\\"
        b'\xdc\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r'
        b'\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
